@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 #include "devicedetails.h"
 
 gas::gas(unsigned char oxygen, unsigned char helium, unsigned char type, unsigned char depth) :
@@ -27,6 +28,7 @@ DeviceDetails::DeviceDetails(QObject *parent) :
 	aGFLow(0),
 	aGFHigh(0),
 	aGFSelectable(0),
+	vpmConservatism(0),
 	saturation(0),
 	desaturation(0),
 	lastDeco(0),
@@ -55,8 +57,10 @@ DeviceDetails::DeviceDetails(QObject *parent) :
 	alarmDepth(0),
 	leftButtonSensitivity(0),
 	rightButtonSensitivity(0),
+	buttonSensitivity(0),
 	bottomGasConsumption(0),
 	decoGasConsumption(0),
+	travelGasConsumption(0),
 	modWarning(false),
 	dynamicAscendRate(false),
 	graphicalSpeedIndicator(false),
