@@ -9,10 +9,10 @@
 #include <stdbool.h>
 #include <time.h>
 #include <math.h>
-#include <zip.h>
 #include <string.h>
-#include <sys/stat.h>
+#include <stdio.h>
 
+#include "divemode.h"
 #include "equipment.h"
 
 #ifdef __cplusplus
@@ -21,8 +21,6 @@ extern "C" {
 
 extern int last_xml_version;
 
-enum divemode_t {OC, CCR, PSCR, FREEDIVE, NUM_DIVEMODE, UNDEF_COMP_TYPE};	// Flags (Open-circuit and Closed-circuit-rebreather) for setting dive computer type
-
 extern const char *cylinderuse_text[NUM_GAS_USE];
 extern const char *divemode_text_ui[];
 extern const char *divemode_text[];
@@ -247,7 +245,7 @@ extern bool autogroup;
 struct dive *unregister_dive(int idx);
 extern void delete_single_dive(int idx);
 
-extern int run_survey, verbose, quit, force_root;
+extern int run_survey, quit, force_root;
 
 extern struct dive_table dive_table;
 extern struct dive displayed_dive;
@@ -289,9 +287,6 @@ extern bool dive_site_has_gps_location(const struct dive_site *ds);
 extern int dive_has_gps_location(const struct dive *dive);
 extern location_t dive_get_gps_location(const struct dive *d);
 
-extern int report_error(const char *fmt, ...);
-extern void set_error_cb(void(*cb)(char *));	// Callback takes ownership of passed string
-
 extern bool dive_within_time_range(struct dive *dive, timestamp_t when, timestamp_t offset);
 extern bool time_during_dive_with_offset(struct dive *dive, timestamp_t when, timestamp_t offset);
 struct dive *find_dive_n_near(timestamp_t when, int n, timestamp_t offset);
@@ -320,15 +315,6 @@ struct user_info {
 };
 
 extern void subsurface_user_info(struct user_info *);
-extern int subsurface_rename(const char *path, const char *newpath);
-extern int subsurface_dir_rename(const char *path, const char *newpath);
-extern int subsurface_open(const char *path, int oflags, mode_t mode);
-extern FILE *subsurface_fopen(const char *path, const char *mode);
-extern void *subsurface_opendir(const char *path);
-extern int subsurface_access(const char *path, int mode);
-extern int subsurface_stat(const char* path, struct stat* buf);
-extern struct zip *subsurface_zip_open_readonly(const char *path, int flags, int *errorp);
-extern int subsurface_zip_close(struct zip *zip);
 extern void subsurface_console_init(void);
 extern void subsurface_console_exit(void);
 extern bool subsurface_user_is_root(void);
@@ -376,7 +362,7 @@ extern void copy_cylinders(const struct dive *s, struct dive *d, bool used_only)
 extern void copy_samples(const struct divecomputer *s, struct divecomputer *d);
 extern bool is_cylinder_used(const struct dive *dive, int idx);
 extern bool is_cylinder_prot(const struct dive *dive, int idx);
-extern void fill_default_cylinder(cylinder_t *cyl);
+extern void fill_default_cylinder(struct dive *dive, int idx);
 extern void add_gas_switch_event(struct dive *dive, struct divecomputer *dc, int time, int idx);
 extern struct event *add_event(struct divecomputer *dc, unsigned int time, int type, int flags, int value, const char *name);
 extern void remove_event(struct event *event);
@@ -418,76 +404,9 @@ extern void subsurface_command_line_exit(int *, char ***);
 
 #define DECOTIMESTEP 60 /* seconds. Unit of deco stop times */
 
-struct deco_state {
-	double tissue_n2_sat[16];
-	double tissue_he_sat[16];
-	double tolerated_by_tissue[16];
-	double tissue_inertgas_saturation[16];
-	double buehlmann_inertgas_a[16];
-	double buehlmann_inertgas_b[16];
-
-	double max_n2_crushing_pressure[16];
-	double max_he_crushing_pressure[16];
-
-	double crushing_onset_tension[16];            // total inert gas tension in the t* moment
-	double n2_regen_radius[16];                   // rs
-	double he_regen_radius[16];
-	double max_ambient_pressure;                  // last moment we were descending
-
-	double bottom_n2_gradient[16];
-	double bottom_he_gradient[16];
-
-	double initial_n2_gradient[16];
-	double initial_he_gradient[16];
-	pressure_t first_ceiling_pressure;
-	pressure_t max_bottom_ceiling_pressure;
-	int ci_pointing_to_guiding_tissue;
-	double gf_low_pressure_this_dive;
-	int deco_time;
-	bool icd_warning;
-};
-
-extern void add_segment(struct deco_state *ds, double pressure, struct gasmix gasmix, int period_in_seconds, int setpoint, enum divemode_t divemode, int sac);
 extern bool is_dc_planner(const struct divecomputer *dc);
 extern bool has_planned(const struct dive *dive, bool planned);
 
-/* this should be converted to use our types */
-struct divedatapoint {
-	int time;
-	depth_t depth;
-	int cylinderid;
-	pressure_t minimum_gas;
-	int setpoint;
-	bool entered;
-	struct divedatapoint *next;
-	enum divemode_t divemode;
-};
-
-struct diveplan {
-	timestamp_t when;
-	int surface_pressure; /* mbar */
-	int bottomsac;	/* ml/min */
-	int decosac;	  /* ml/min */
-	int salinity;
-	short gflow;
-	short gfhigh;
-	short vpmb_conservatism;
-	struct divedatapoint *dp;
-	int eff_gflow, eff_gfhigh;
-	int surface_interval;
-};
-
-struct divedatapoint *plan_add_segment(struct diveplan *diveplan, int duration, int depth, int cylinderid, int po2, bool entered, enum divemode_t divemode);
-struct divedatapoint *create_dp(int time_incr, int depth, int cylinderid, int po2);
-#if DEBUG_PLAN
-void dump_plan(struct diveplan *diveplan);
-#endif
-struct decostop {
-	int depth;
-	int time;
-};
-extern bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, int timestep, struct decostop *decostoptable, struct deco_state **cached_datap, bool is_planner, bool show_disclaimer);
-
 /* Since C doesn't have parameter-based overloading, two versions of get_next_event. */
 extern const struct event *get_next_event(const struct event *event, const char *name);
 extern struct event *get_next_event_mutable(struct event *event, const char *name);
@@ -514,8 +433,6 @@ extern void set_git_prefs(const char *prefs);
 extern char *get_dive_date_c_string(timestamp_t when);
 extern void update_setpoint_events(const struct dive *dive, struct divecomputer *dc);
 
-extern void average_max_depth(struct diveplan *dive, int *avg_depth, int *max_depth);
-
 #ifdef __cplusplus
 }
 
