@@ -3,15 +3,14 @@
 #define DIVECOMPUTER_H
 
 #include <QString>
-#include <QMap>
+#include <QVector>
 #include <stdint.h>
 
 class DiveComputerNode {
 public:
-	DiveComputerNode(QString m, uint32_t d, QString s, QString f, QString n)
-	    : model(m), deviceId(d), serialNumber(s), firmware(f), nickName(n) {};
 	bool operator==(const DiveComputerNode &a) const;
 	bool operator!=(const DiveComputerNode &a) const;
+	bool operator<(const DiveComputerNode &a) const;
 	bool changesValues(const DiveComputerNode &b) const;
 	void showchanges(const QString &n, const QString &s, const QString &f) const;
 	QString model;
@@ -23,15 +22,14 @@ public:
 
 class DiveComputerList {
 public:
-	DiveComputerList();
-	~DiveComputerList();
 	const DiveComputerNode *getExact(const QString &m, uint32_t d);
 	const DiveComputerNode *get(const QString &m);
 	void addDC(QString m, uint32_t d, QString n = QString(), QString s = QString(), QString f = QString());
 	DiveComputerNode matchDC(const QString &m, uint32_t d);
 	DiveComputerNode matchModel(const QString &m);
-	QMultiMap<QString, DiveComputerNode> dcMap;
-	QMultiMap<QString, DiveComputerNode> dcWorkingMap;
+
+	// Keep the dive computers in a vector sorted by (model, deviceId)
+	QVector<DiveComputerNode> dcs;
 };
 
 extern DiveComputerList dcList;
