@@ -39,16 +39,30 @@ typedef struct
 	const char *description; /* "integrated", "belt", "ankle" */
 } weightsystem_t;
 
+/* Table of weightsystems. Attention: this stores weightsystems,
+ * *not* pointers * to weightsystems. This has two crucial
+ * consequences:
+ * 1) Pointers to weightsystems are not stable. They may be
+ *    invalidated if the table is reallocated.
+ * 2) add_to_weightsystem_table(), etc. takes ownership of the
+ *    weightsystem. Notably of the description string */
+struct weightsystem_table {
+	int nr, allocated;
+	weightsystem_t *weightsystems;
+};
+
 #define MAX_CYLINDERS (20)
-#define MAX_WEIGHTSYSTEMS (6)
 #define MAX_TANK_INFO (100)
 #define MAX_WS_INFO (100)
 
+extern int cylinderuse_from_text(const char *text);
+extern void copy_weights(const struct weightsystem_table *s, struct weightsystem_table *d);
+extern void add_cloned_weightsystem(struct weightsystem_table *t, weightsystem_t ws);
 extern void add_cylinder_description(const cylinder_type_t *);
 extern void add_weightsystem_description(const weightsystem_t *);
+extern bool same_weightsystem(weightsystem_t w1, weightsystem_t w2);
 extern bool cylinder_nodata(const cylinder_t *cyl);
 extern bool cylinder_none(const cylinder_t *cyl);
-extern bool weightsystem_none(const weightsystem_t *ws);
 extern void remove_cylinder(struct dive *dive, int idx);
 extern void remove_weightsystem(struct dive *dive, int idx);
 extern void reset_cylinders(struct dive *dive, bool track_gas);
@@ -58,6 +72,10 @@ extern int find_best_gasmix_match(struct gasmix mix, const cylinder_t array[]);
 extern void dump_cylinders(struct dive *dive, bool verbose);
 #endif
 
+/* Weightsystem table functions */
+extern void clear_weightsystem_table(struct weightsystem_table *);
+extern void add_to_weightsystem_table(struct weightsystem_table *, int idx, weightsystem_t ws);
+
 void get_gas_string(struct gasmix gasmix, char *text, int len);
 const char *gasname(struct gasmix gasmix);
 
