@@ -352,20 +352,19 @@ static void debug_print_pressures(struct plot_info *pi)
 	int i;
 	for (i = 0; i < pi->nr; i++) {
 		struct plot_data *entry = pi->entry + i;
-		printf("%5d |%9d | %9d || %9d | %9d |\n", i, SENSOR_PRESSURE(entry), INTERPOLATED_PRESSURE(entry), DILUENT_PRESSURE(entry), INTERPOLATED_DILUENT_PRESSURE(entry));
+		printf("%5d |%9d | %9d |\n", i, get_plot_sensor_pressure(entry), get_plot_interpolated_pressure(entry));
 	}
 }
 #endif
 
-/* This function goes through the list of tank pressures, either SENSOR_PRESSURE(entry) or O2CYLINDER_PRESSURE(entry),
- * of structure plot_info for the dive profile where each item in the list corresponds to one point (node) of the
- * profile. It finds values for which there are no tank pressures (pressure==0). For each missing item (node) of
- * tank pressure it creates a pr_track_alloc structure that represents a segment on the dive profile and that
- * contains tank pressures. There is a linked list of pr_track_alloc structures for each cylinder. These pr_track_alloc
- * structures ultimately allow for filling the missing tank pressure values on the dive profile using the depth_pressure
- * of the dive. To do this, it calculates the summed pressure-time value for the duration of the dive and stores these
- * in the pr_track_alloc structures. If diluent_flag = 1, then DILUENT_PRESSURE(entry) is used instead of SENSOR_PRESSURE.
- * This function is called by create_plot_info_new() in profile.c
+/* This function goes through the list of tank pressures, of structure plot_info for the dive profile where each
+ * item in the list corresponds to one point (node) of the profile. It finds values for which there are no tank
+ * pressures (pressure==0). For each missing item (node) of tank pressure it creates a pr_track_alloc structure
+ * that represents a segment on the dive profile and that contains tank pressures. There is a linked list of
+ * pr_track_alloc structures for each cylinder. These pr_track_alloc structures ultimately allow for filling
+ * the missing tank pressure values on the dive profile using the depth_pressure of the dive. To do this, it
+ * calculates the summed pressure-time value for the duration of the dive and stores these * in the pr_track_alloc
+ * structures. This function is called by create_plot_info_new() in profile.c
  */
 void populate_pressure_information(struct dive *dive, struct divecomputer *dc, struct plot_info *pi, int sensor)
 {
@@ -388,7 +387,7 @@ void populate_pressure_information(struct dive *dive, struct divecomputer *dc, s
 	first = last = -1;
 	for (int i = 0; i < pi->nr; i++) {
 		struct plot_data *entry = pi->entry + i;
-		unsigned pressure = SENSOR_PRESSURE(entry, sensor);
+		int pressure = get_plot_sensor_pressure(entry, sensor);
 
 		if (!pressure)
 			continue;
@@ -417,7 +416,7 @@ void populate_pressure_information(struct dive *dive, struct divecomputer *dc, s
 
 	for (int i = first; i <= last; i++) {
 		struct plot_data *entry = pi->entry + i;
-		unsigned pressure = SENSOR_PRESSURE(entry, sensor);
+		int pressure = get_plot_sensor_pressure(entry, sensor);
 		int time = entry->sec;
 
 		while (ev && ev->time.seconds <= time) {   // Find 1st gaschange event after 
@@ -446,7 +445,7 @@ void populate_pressure_information(struct dive *dive, struct divecomputer *dc, s
 		// until we get back to this cylinder.
 		if (cyl != sensor) {
 			current = NULL;
-			SENSOR_PRESSURE(entry, sensor) = 0;
+			set_plot_pressure_data(entry, SENSOR_PR, sensor, 0);
 			continue;
 		}
 
