@@ -311,8 +311,8 @@ static int divinglog_dive(void *param, int columns, char **data, char **column)
 		state->cur_dive->watertemp.mkelvin = C_to_mkelvin(atol(data[9]));
 
 	if (data[10]) {
-		state->cur_dive->weightsystem[0].weight.grams = atol(data[10]) * 1000;
-		state->cur_dive->weightsystem[0].description = strdup(translate("gettextFromC", "unknown"));
+		weightsystem_t ws = { { atol(data[10]) * 1000 }, translate("gettextFromC", "unknown") };
+		add_cloned_weightsystem(&state->cur_dive->weightsystems, ws);
 	}
 
 	if (data[11])
