@@ -6,8 +6,7 @@
 struct metadata {
 	timestamp_t	timestamp;
 	duration_t	duration;
-	degrees_t	latitude;
-	degrees_t	longitude;
+	location_t	location;
 };
 
 enum mediatype_t {
