@@ -3,11 +3,12 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "dive.h"
+#include "errorhelper.h"
 #include "ssrf.h"
 #include "subsurface-string.h"
 #include "gettext.h"
 #include "divelist.h"
+#include "file.h"
 #include "libdivecomputer.h"
 
 /*
