@@ -11,6 +11,7 @@
 #include <string.h>
 #include "dive.h"
 #include "deco.h"
+#include "units.h"
 #include "divelist.h"
 #include "planner.h"
 #include "gettext.h"
@@ -24,9 +25,12 @@ static int diveplan_duration(struct diveplan *diveplan)
 {
 	struct divedatapoint *dp = diveplan->dp;
 	int duration = 0;
+	int lastdepth = 0;
 	while(dp) {
-		if (dp->time > duration)
+		if (dp->time > duration && (dp->depth.mm > SURFACE_THRESHOLD || lastdepth > SURFACE_THRESHOLD)) {
 			duration = dp->time;
+			lastdepth = dp->depth.mm;
+		}
 		dp = dp->next;
 	}
 	return (duration + 30) / 60;
@@ -112,8 +116,8 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 
 	if (show_disclaimer) {
 		put_string(&buf, "<div><b>");
-		put_format(&buf, translate("gettextFromC", "DISCLAIMER / WARNING: THIS IS A NEW IMPLEMENTATION OF THE %s "
-			"ALGORITHM AND A DIVE PLANNER IMPLEMENTATION BASED ON THAT WHICH HAS "
+		put_format(&buf, translate("gettextFromC", "DISCLAIMER / WARNING: THIS IMPLEMENTATION OF THE %s "
+			"ALGORITHM AND A DIVE PLANNER IMPLEMENTATION BASED ON THAT HAS "
 			"RECEIVED ONLY A LIMITED AMOUNT OF TESTING. WE STRONGLY RECOMMEND NOT TO "
 			"PLAN DIVES SIMPLY BASED ON THE RESULTS GIVEN HERE."), deco);
 		put_string(&buf, "</b><br></div>");
@@ -193,6 +197,9 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 		    !rebreatherchange_before &&
 		    !rebreatherchange_after)
 			continue;
+		// Ignore final surface segment for notes
+		if (lastdepth == 0 && dp->depth.mm == 0 && !dp->next)
+			continue;
 		if ((dp->time - lasttime < 10 && lastdepth == dp->depth.mm) && !(gaschange_after && dp->next && dp->depth.mm != dp->next->depth.mm))
 			continue;
 
@@ -414,7 +421,7 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 	put_string(&buf, "<br>");
 
 	const char *depth_unit;
-	int altitude = (int) get_depth_units((int) (log(1013.0 / diveplan->surface_pressure) * 7800000), NULL, &depth_unit);
+	int altitude = (int) get_depth_units((int) (pressure_to_altitude(diveplan->surface_pressure)), NULL, &depth_unit);
 
 	put_format_loc(&buf, translate("gettextFromC", "ATM pressure: %dmbar (%d%s)<br></div>"), diveplan->surface_pressure, altitude, depth_unit);
 
@@ -445,6 +452,8 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 		char warning[1000] = "";
 		char mingas[1000] = "";
 		cylinder_t *cyl = &dive->cylinder[gasidx];
+		if (cyl->cylinder_use == NOT_USED)
+			continue;
 		if (cylinder_none(cyl))
 			break;
 
