@@ -5,7 +5,7 @@
 #include <QLibraryInfo>
 #include <QTextCodec>
 #include "qthelper.h"
-#include "dive.h" // for "verbose"
+#include "errorhelper.h"
 #include "core/settings/qPref.h"
 
 char *settings_suffix = NULL;
