@@ -10,6 +10,8 @@
 #include "subsurfacesysinfo.h"
 #include "version.h"
 #include "divecomputer.h"
+#include "errorhelper.h"
+#include "planner.h"
 #include "time.h"
 #include "gettextfromc.h"
 #include "applicationstate.h"
