@@ -5,8 +5,9 @@
 #include <stdint.h>
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
-#include "dive.h"
-#include "divelist.h"
+#include "core/pref.h"
+
+struct picture;
 
 // 1) Types
 
@@ -26,18 +27,13 @@ QString distance_string(int distanceInMeters);
 bool gpsHasChanged(struct dive *dive, struct dive *master, const QString &gps_text, bool *parsed_out = 0);
 QList<int> getDivesInTrip(struct dive_trip *trip);
 QString get_gas_string(struct gasmix gas);
-QString get_divepoint_gas_string(struct dive *d, const divedatapoint& dp);
+QString get_divepoint_gas_string(struct dive *d, const struct divedatapoint &dp);
 QString get_taglist_string(struct tag_entry *tag_list);
 void read_hashes();
 void write_hashes();
 QString thumbnailFileName(const QString &filename);
 void learnPictureFilename(const QString &originalName, const QString &localName);
 QString localFilePath(const QString &originalFilename);
-weight_t string_to_weight(const char *str);
-depth_t string_to_depth(const char *str);
-pressure_t string_to_pressure(const char *str);
-volume_t string_to_volume(const char *str, pressure_t workp);
-fraction_t string_to_fraction(const char *str);
 int getCloudURL(QString &filename);
 bool parseGpsText(const QString &gps_text, double *latitude, double *longitude);
 void init_proxy();
@@ -162,6 +158,11 @@ void print_qt_versions();
 void lock_planner();
 void unlock_planner();
 xsltStylesheetPtr get_stylesheet(const char *name);
+weight_t string_to_weight(const char *str);
+depth_t string_to_depth(const char *str);
+pressure_t string_to_pressure(const char *str);
+volume_t string_to_volume(const char *str, pressure_t workp);
+fraction_t string_to_fraction(const char *str);
 
 #ifdef __cplusplus
 }
