@@ -8,6 +8,8 @@
 #include "qthelper.h"
 #include "gettext.h"
 #include "divesite.h"
+#include "errorhelper.h"
+#include "file.h"
 #include "tag.h"
 #include "trip.h"
 #include <stdio.h>
