@@ -58,18 +58,6 @@ static QString getPressures(struct dive *dive, int i, enum returnPressureSelecto
 DiveObjectHelper::DiveObjectHelper(struct dive *d) :
 	m_dive(d)
 {
-	m_cyls.clear();
-	for (int i = 0; i < MAX_CYLINDERS; i++) {
-		//Don't add blank cylinders, only those that have been defined.
-		if (m_dive->cylinder[i].type.description)
-			m_cyls.append(new CylinderObjectHelper(&m_dive->cylinder[i]));
-	}
-}
-
-DiveObjectHelper::~DiveObjectHelper()
-{
-while (!m_cyls.isEmpty())
-	delete m_cyls.takeFirst();
 }
 
 int DiveObjectHelper::number() const
@@ -254,7 +242,7 @@ QStringList DiveObjectHelper::weights() const
 
 bool DiveObjectHelper::singleWeight() const
 {
-	return m_dive->weightsystems.nr == 1;
+	return m_dive->weightsystems.nr <= 1;
 }
 
 QString DiveObjectHelper::weight(int idx) const
@@ -314,9 +302,15 @@ QString DiveObjectHelper::cylinder(int idx) const
 	return getFormattedCylinder(m_dive, idx);
 }
 
-QList<CylinderObjectHelper*> DiveObjectHelper::cylinderObjects() const
+QVector<CylinderObjectHelper> DiveObjectHelper::cylinderObjects() const
 {
-	return m_cyls;
+	QVector<CylinderObjectHelper> res;
+	for (int i = 0; i < MAX_CYLINDERS; i++) {
+		//Don't add blank cylinders, only those that have been defined.
+		if (m_dive->cylinder[i].type.description)
+			res.append(CylinderObjectHelper(&m_dive->cylinder[i])); // no emplace for QVector. :(
+	}
+	return res;
 }
 
 QString DiveObjectHelper::tripId() const
