@@ -6,6 +6,7 @@
 #include <QObject>
 #include <QString>
 #include <QStringList>
+#include <QVector>
 #include <QVariant>
 
 class DiveObjectHelper : public QObject {
@@ -38,7 +39,7 @@ class DiveObjectHelper : public QObject {
 	Q_PROPERTY(QString suit READ suit CONSTANT)
 	Q_PROPERTY(QStringList cylinderList READ cylinderList CONSTANT)
 	Q_PROPERTY(QStringList cylinders READ cylinders CONSTANT)
-	Q_PROPERTY(QList<CylinderObjectHelper*> cylinderObjects READ cylinderObjects CONSTANT)
+	Q_PROPERTY(QVector<CylinderObjectHelper> cylinderObjects READ cylinderObjects CONSTANT)
 	Q_PROPERTY(QString tripId READ tripId CONSTANT)
 	Q_PROPERTY(int tripNrDives READ tripNrDives CONSTANT)
 	Q_PROPERTY(int maxcns READ maxcns CONSTANT)
@@ -51,8 +52,7 @@ class DiveObjectHelper : public QObject {
 	Q_PROPERTY(QString fullText READ fullText CONSTANT)
 	Q_PROPERTY(QString fullTextNoNotes READ fullTextNoNotes CONSTANT)
 public:
-	DiveObjectHelper(struct dive *dive = NULL);
-	~DiveObjectHelper();
+	DiveObjectHelper(struct dive *dive);
 	int number() const;
 	int id() const;
 	struct dive *getDive() const;
@@ -84,7 +84,7 @@ public:
 	QStringList cylinderList() const;
 	QStringList cylinders() const;
 	QString cylinder(int idx) const;
-	QList<CylinderObjectHelper*> cylinderObjects() const;
+	QVector<CylinderObjectHelper> cylinderObjects() const;
 	QString tripId() const;
 	int tripNrDives() const;
 	int maxcns() const;
@@ -99,7 +99,6 @@ public:
 
 private:
 	struct dive *m_dive;
-	QList<CylinderObjectHelper*> m_cyls;
 };
 	Q_DECLARE_METATYPE(DiveObjectHelper *)
 
