@@ -26,6 +26,8 @@
 #include "uemis.h"
 #include "divelist.h"
 #include "divesite.h"
+#include "errorhelper.h"
+#include "file.h"
 #include "tag.h"
 #include "core/subsurface-string.h"
 
