@@ -7,15 +7,10 @@
 class WindowTitleUpdate : public QObject
 {
 	Q_OBJECT
-public:
-	explicit WindowTitleUpdate(QObject *parent = 0);
-	~WindowTitleUpdate();
-	static WindowTitleUpdate *instance();
-	void emitSignal();
 signals:
 	void updateTitle();
-private:
-	static WindowTitleUpdate *m_instance;
 };
 
+extern WindowTitleUpdate windowTitleUpdate;
+
 #endif // WINDOWTITLEUPDATE_H
