@@ -1,18 +1,18 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "desktop-widgets/configuredivecomputerdialog.h"
 
-#include "core/qthelper.h"
-#include "desktop-widgets/mainwindow.h"
 #include "core/display.h"
-#include "core/subsurface-qt/SettingsObjectWrapper.h"
+#include "core/qthelper.h"
+#include "core/settings/qPrefDiveComputer.h"
+#include "desktop-widgets/mainwindow.h"
 // For fill_computer_list, descriptorLookup
 #include "core/downloadfromdcthread.h"
 
 #include <QFileDialog>
 #include <QMessageBox>
-#include <QSettings>
 #include <QNetworkReply>
 #include <QProgressDialog>
+#include <QSettings>
 
 GasSpinBoxItemDelegate::GasSpinBoxItemDelegate(QObject *parent, column_type type) : QStyledItemDelegate(parent), type(type)
 {
@@ -21,7 +21,7 @@ GasSpinBoxItemDelegate::~GasSpinBoxItemDelegate()
 {
 }
 
-QWidget *GasSpinBoxItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem&, const QModelIndex&) const
+QWidget *GasSpinBoxItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &) const
 {
 	// Create the spinbox and give it it's settings
 	QSpinBox *sb = new QSpinBox(parent);
@@ -65,7 +65,7 @@ GasTypeComboBoxItemDelegate::~GasTypeComboBoxItemDelegate()
 {
 }
 
-QWidget *GasTypeComboBoxItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem&, const QModelIndex&) const
+QWidget *GasTypeComboBoxItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &) const
 {
 	// Create the combobox and populate it
 	QComboBox *cb = new QComboBox(parent);
@@ -132,9 +132,8 @@ ConfigureDiveComputerDialog::ConfigureDiveComputerDialog(QWidget *parent) : QDia
 
 	memset(&device_data, 0, sizeof(device_data));
 	fill_computer_list();
-	auto dc = SettingsObjectWrapper::instance()->dive_computer_settings;
-	if (!dc->dc_device().isEmpty())
-		ui.device->setEditText(dc->dc_device());
+	if (!qPrefDiveComputer::device().isEmpty())
+		ui.device->setEditText(qPrefDiveComputer::device());
 
 	ui.DiveComputerList->setCurrentRow(0);
 	on_DiveComputerList_currentRowChanged(0);
@@ -237,7 +236,7 @@ OstcFirmwareCheck::OstcFirmwareCheck(QString product) : parent(0)
 {
 	QUrl url;
 	memset(&devData, 1, sizeof(devData));
-	if (product == "OSTC 3" || product == "OSTC 3+" || product == "OSTC cR") {
+	if (product == "OSTC 3" || product == "OSTC 3+" || product == "OSTC cR" || product == "OSTC Plus") {
 		url = QUrl("http://www.heinrichsweikamp.net/autofirmware/ostc3_changelog.txt");
 		latestFirmwareHexFile = QString("http://www.heinrichsweikamp.net/autofirmware/ostc3_firmware.hex");
 	} else if (product == "OSTC Sport") {
@@ -287,7 +286,7 @@ void OstcFirmwareCheck::checkLatest(QWidget *_parent, device_data_t *data)
 		Y = (firmwareOnDevice & 0x07C0) >> 6;
 		Z = (firmwareOnDevice & 0x003E) >> 1;
 		beta = firmwareOnDevice & 0x0001;
-		firmwareOnDeviceString = QString("%1.%2.%3%4").arg(X).arg(Y).arg(Z).arg(beta?" beta":"");
+		firmwareOnDeviceString = QString("%1.%2.%3%4").arg(X).arg(Y).arg(Z).arg(beta ? " beta" : "");
 		latestFirmwareAvailableNumber = (fwParts[0].toInt() << 11) + (fwParts[1].toInt() << 6) + (fwParts[2].toInt() << 1);
 	} else { // OSTC 3, Sport, Cr
 		firmwareOnDeviceString = QString("%1.%2").arg(firmwareOnDevice / 256).arg(firmwareOnDevice % 256);
@@ -358,7 +357,7 @@ ConfigureDiveComputerDialog::~ConfigureDiveComputerDialog()
 	delete config;
 }
 
-void ConfigureDiveComputerDialog::closeEvent(QCloseEvent*)
+void ConfigureDiveComputerDialog::closeEvent(QCloseEvent *)
 {
 	dc_close();
 
@@ -399,11 +398,11 @@ static void fillDeviceList(const char *name, void *data)
 	comboBox->addItem(name);
 }
 
-void ConfigureDiveComputerDialog::fill_device_list(int dc_type)
+void ConfigureDiveComputerDialog::fill_device_list(unsigned int transport)
 {
 	int deviceIndex;
 	ui.device->clear();
-	deviceIndex = enumerate_devices(fillDeviceList, ui.device, dc_type);
+	deviceIndex = enumerate_devices(fillDeviceList, ui.device, transport);
 	if (deviceIndex >= 0)
 		ui.device->setCurrentIndex(deviceIndex);
 }
@@ -900,7 +899,8 @@ void ConfigureDiveComputerDialog::getDeviceData()
 {
 #ifdef BT_SUPPORT
 	QString device = ui.bluetoothMode && btDeviceSelectionDialog ?
-		btDeviceSelectionDialog->getSelectedDeviceAddress() : ui.device->currentText();
+				 btDeviceSelectionDialog->getSelectedDeviceAddress() :
+				 ui.device->currentText();
 #else
 	QString device = ui.device->currentText();
 #endif
@@ -911,11 +911,10 @@ void ConfigureDiveComputerDialog::getDeviceData()
 	device_data.descriptor = descriptorLookup.value(selected_vendor + selected_product);
 	device_data.deviceid = device_data.diveid = 0;
 
-	auto dc = SettingsObjectWrapper::instance()->dive_computer_settings;
-	dc->setDevice(device_data.devname);
+	qPrefDiveComputer::set_device(device_data.devname);
 #ifdef BT_SUPPORT
 	if (ui.bluetoothMode && btDeviceSelectionDialog)
-		dc->setDeviceName(btDeviceSelectionDialog->getSelectedDeviceName());
+		qPrefDiveComputer::set_device_name(btDeviceSelectionDialog->getSelectedDeviceName());
 #endif
 }
 
@@ -1445,13 +1444,7 @@ void ConfigureDiveComputerDialog::on_DiveComputerList_currentRowChanged(int curr
 		/* Not Supported */
 		return;
 	}
-
-	int dcType = DC_TYPE_SERIAL;
-
-
-	if (selected_vendor == QString("Uemis"))
-		dcType = DC_TYPE_UEMIS;
-	fill_device_list(dcType);
+	fill_device_list(DC_TRANSPORT_SERIAL);
 }
 
 void ConfigureDiveComputerDialog::checkLogFile(int state)
