@@ -27,6 +27,7 @@
 #include "qt-models/divepicturemodel.h"
 #include "core/metrics.h"
 #include "desktop-widgets/simplewidgets.h"
+#include "desktop-widgets/mapwidget.h"
 
 DiveListView::DiveListView(QWidget *parent) : QTreeView(parent), mouseClickSelection(false),
 	currentLayout(DiveTripModelBase::TREE), dontEmitDiveChangedSignal(false), selectionSaved(false),
@@ -455,6 +456,27 @@ void DiveListView::selectDives(const QList<int> &newDiveSelection)
 			scrollTo(idx.parent());
 		scrollTo(idx);
 	}
+
+	// update the selected-flag for the dive sites.
+	// the actual reloading of the dive sites will be perfomed
+	// by the main-window in response to the divesSelected signal
+	// emitted below.
+	// But don't do this if we are in divesite mode, because then
+	// the dive-site selection is controlled by the filter not
+	// by the selected dives.
+	if (!MultiFilterSortModel::instance()->diveSiteMode()) {
+		QVector<dive_site *> selectedSites;
+		for (int idx: newDiveSelection) {
+			dive *d = get_dive(idx);
+			if (!d)
+				continue;
+			dive_site *ds = d->dive_site;
+			if (ds && !selectedSites.contains(ds))
+				selectedSites.append(ds);
+		}
+		MapWidget::instance()->setSelected(selectedSites);
+	}
+
 	// now that everything is up to date, update the widgets
 	emit divesSelected();
 	dontEmitDiveChangedSignal = false;
@@ -670,8 +692,25 @@ void DiveListView::selectionChanged(const QItemSelection &selected, const QItemS
 			select_dive(dive);
 		}
 	}
-	if (!dontEmitDiveChangedSignal)
+	if (!dontEmitDiveChangedSignal) {
+		// When receiving the divesSelected signal the main window will
+		// instruct the map to update the flags. Thus, make sure that
+		// the selected maps are registered correctly.
+		// But don't do this if we are in divesite mode, because then
+		// the dive-site selection is controlled by the filter not
+		// by the selected dives.
+		if (!MultiFilterSortModel::instance()->diveSiteMode()) {
+			QVector<dive_site *> selectedSites;
+			for (QModelIndex index: selectionModel()->selection().indexes()) {
+				const QAbstractItemModel *model = index.model();
+				struct dive *dive = model->data(index, DiveTripModelBase::DIVE_ROLE).value<struct dive *>();
+				if (dive && dive->dive_site)
+					selectedSites.push_back(dive->dive_site);
+			}
+			MapWidget::instance()->setSelected(selectedSites);
+		}
 		emit divesSelected();
+	}
 
 	// Display the new, processed, selection
 	QTreeView::selectionChanged(selectionModel()->selection(), newDeselected);
