@@ -16,6 +16,7 @@
 #include <QLineEdit>
 #include <QNetworkAccessManager>
 #include "qt-models/divetripmodel.h"
+#include "core/subsurface-qt/DiveListNotifier.h"
 
 class DiveListView : public QTreeView {
 	Q_OBJECT
@@ -38,9 +39,11 @@ public:
 	void rememberSelection();
 	void restoreSelection();
 	void contextMenuEvent(QContextMenuEvent *event);
-	QList<dive_trip_t *> selectedTrips();
+	QList<dive_trip *> selectedTrips();
 	static QString lastUsedImageDir();
 	static void updateLastUsedImageDir(const QString &s);
+signals:
+	void divesSelected();
 public
 slots:
 	void toggleColumnVisibilityByIndex();
@@ -62,13 +65,14 @@ slots:
 	void shiftTimes();
 	void loadImages();
 	void loadWebImages();
-	void diveSelectionChanged(const QVector<QModelIndex> &indexes, bool select);
+	void diveSelectionChanged(const QVector<QModelIndex> &indexes);
 	void currentDiveChanged(QModelIndex index);
 	void filterFinished();
+	void tripChanged(dive_trip *trip, TripField);
 private:
 	bool mouseClickSelection;
 	QList<int> expandedRows;
-	DiveTripModel::Layout currentLayout;
+	DiveTripModelBase::Layout currentLayout;
 	QModelIndex contextMenuIndex;
 	bool dontEmitDiveChangedSignal;
 	bool selectionSaved;
@@ -76,14 +80,15 @@ private:
 	QVector<int> initialColumnWidths;
 
 	/* if dive_trip_t is null, there's no problem. */
-	QMultiHash<dive_trip_t *, int> selectedDives;
+	QMultiHash<dive_trip *, int> selectedDives;
+	void resetModel();	// Call after model changed
 	void merge_trip(const QModelIndex &a, const int offset);
 	void setColumnWidths();
 	void calculateInitialColumnWidth(int col);
 	void backupExpandedRows();
 	void restoreExpandedRows();
 	int lastVisibleColumn();
-	void selectTrip(dive_trip_t *trip);
+	void selectTrip(dive_trip *trip);
 	void updateLastImageTimeOffset(int offset);
 	int lastImageTimeOffset();
 	void addToTrip(int delta);
