@@ -9,7 +9,10 @@
 #include <QMimeData>
 #include <QRegExp>
 #include <QUndoStack>
+#include <QPainter>
 #include "core/qthelper.h"
+#include "core/divesite.h"
+#include "core/trip.h"
 #include "core/import-csv.h"
 
 static QString subsurface_mimedata = "subsurface/csvcolumns";
@@ -69,7 +72,7 @@ ColumnNameProvider::ColumnNameProvider(QObject *parent) : QAbstractListModel(par
 		       tr("O₂") << tr("He") << tr("Sample time") << tr("Sample depth") << tr("Sample temperature") << tr("Sample pO₂") << tr("Sample CNS") << tr("Sample NDL") <<
 		       tr("Sample TTS") << tr("Sample stopdepth") << tr("Sample pressure") <<
 		       tr("Sample sensor1 pO₂") << tr("Sample sensor2 pO₂") << tr("Sample sensor3 pO₂") <<
-		       tr("Sample setpoint") << tr("Visibility") << tr("Rating");
+		       tr("Sample setpoint") << tr("Visibility") << tr("Rating") << tr("Sample heartrate");
 }
 
 bool ColumnNameProvider::insertRows(int row, int, const QModelIndex&)
@@ -240,7 +243,8 @@ ColumnNameResult::ColumnNameResult(QObject *parent) : QAbstractTableModel(parent
 
 }
 
-void ColumnNameResult::swapValues(int firstIndex, int secondIndex) {
+void ColumnNameResult::swapValues(int firstIndex, int secondIndex)
+{
 	QString one = columnNames[firstIndex];
 	QString two = columnNames[secondIndex];
 	setData(index(0, firstIndex), QVariant(two), Qt::EditRole);
@@ -829,6 +833,8 @@ int DiveLogImportDialog::setup_csv_params(QStringList r, char **params, int pnr)
 	params[pnr++] = intdup(r.indexOf(tr("Sample stopdepth")));
 	params[pnr++] = strdup("pressureField");
 	params[pnr++] = intdup(r.indexOf(tr("Sample pressure")));
+	params[pnr++] = strdup("heartBeat");
+	params[pnr++] = intdup(r.indexOf(tr("Sample heartrate")));
 	params[pnr++] = strdup("setpointField");
 	params[pnr++] = intdup(r.indexOf(tr("Sample setpoint")));
 	params[pnr++] = strdup("visibilityField");
@@ -899,14 +905,16 @@ int DiveLogImportDialog::parseTxtHeader(QString fileName, char **params, int pnr
 void DiveLogImportDialog::on_buttonBox_accepted()
 {
 	struct dive_table table = { 0 };
+	struct trip_table trips = { 0 };
+	struct dive_site_table sites = { 0 };
 	QStringList r = resultModel->result();
 	if (ui->knownImports->currentText() != "Manual import") {
 		for (int i = 0; i < fileNames.size(); ++i) {
 			if (ui->knownImports->currentText() == "Seabear CSV") {
-				parse_seabear_log(qPrintable(fileNames[i]), &table);
+				parse_seabear_log(qPrintable(fileNames[i]), &table, &trips, &sites);
 			} else if (ui->knownImports->currentText() == "Poseidon MkVI") {
 				QPair<QString, QString> pair = poseidonFileNames(fileNames[i]);
-				parse_txt_file(qPrintable(pair.second), qPrintable(pair.first), &table);
+				parse_txt_file(qPrintable(pair.second), qPrintable(pair.first), &table, &trips, &sites);
 			} else {
 				char *params[49];
 				int pnr = 0;
@@ -923,7 +931,7 @@ void DiveLogImportDialog::on_buttonBox_accepted()
 				pnr = setup_csv_params(r, params, pnr);
 				parse_csv_file(qPrintable(fileNames[i]), params, pnr - 1,
 						specialCSV.contains(ui->knownImports->currentIndex()) ? qPrintable(CSVApps[ui->knownImports->currentIndex()].name) : "csv",
-						&table);
+						&table, &trips, &sites);
 			}
 		}
 	} else {
@@ -987,9 +995,9 @@ void DiveLogImportDialog::on_buttonBox_accepted()
 				params[pnr++] = intdup(r.indexOf(tr("Rating")));
 				params[pnr++] = NULL;
 
-				parse_manual_file(qPrintable(fileNames[i]), params, pnr - 1, &table);
+				parse_manual_file(qPrintable(fileNames[i]), params, pnr - 1, &table, &trips, &sites);
 			} else {
-				char *params[51];
+				char *params[53];
 				int pnr = 0;
 
 				QRegExp apdRe("^.*[/\\][0-9a-zA-Z]*_([0-9]{6})_([0-9]{6})\\.apd");
@@ -1004,22 +1012,20 @@ void DiveLogImportDialog::on_buttonBox_accepted()
 				pnr = setup_csv_params(r, params, pnr);
 				parse_csv_file(qPrintable(fileNames[i]), params, pnr - 1,
 						specialCSV.contains(ui->knownImports->currentIndex()) ? qPrintable(CSVApps[ui->knownImports->currentIndex()].name) : "csv",
-						&table);
+						&table, &trips, &sites);
 			}
 		}
 	}
 
-	process_imported_dives(&table, false, false);
-	autogroup_dives();
-	Command::clear();
-	MainWindow::instance()->refreshDisplay();
+	QString source = fileNames.size() == 1 ? fileNames[0] : tr("multiple files");
+	Command::importDives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS, source);
 }
 
 TagDragDelegate::TagDragDelegate(QObject *parent) : QStyledItemDelegate(parent)
 {
 }
 
-QSize	TagDragDelegate::sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const
+QSize TagDragDelegate::sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const
 {
 	QSize originalSize = QStyledItemDelegate::sizeHint(option, index);
 	return originalSize + QSize(5,5);
