@@ -36,6 +36,7 @@ LocationInformationWidget::LocationInformationWidget(QWidget *parent) : QGroupBo
 	ui.diveSiteCoordinates->installEventFilter(this);
 
 	connect(&diveListNotifier, &DiveListNotifier::diveSiteChanged, this, &LocationInformationWidget::diveSiteChanged);
+	connect(&diveListNotifier, &DiveListNotifier::diveSiteDeleted, this, &LocationInformationWidget::diveSiteDeleted);
 	connect(qPrefUnits::instance(), &qPrefUnits::unit_systemChanged, this, &LocationInformationWidget::unitsChanged);
 	unitsChanged();
 
@@ -133,7 +134,6 @@ void LocationInformationWidget::diveSiteChanged(struct dive_site *ds, int field)
 	switch (field) {
 	case LocationInformationModel::NAME:
 		ui.diveSiteName->setText(diveSite->name);
-		MapWidget::instance()->repopulateLabels();
 		return;
 	case LocationInformationModel::DESCRIPTION:
 		ui.diveSiteDescription->setText(diveSite->description);
@@ -154,7 +154,7 @@ void LocationInformationWidget::diveSiteChanged(struct dive_site *ds, int field)
 			enableLocationButtons(false);
 			ui.diveSiteCoordinates->clear();
 		}
-		MapWidget::instance()->repopulateLabels();
+		return;
 	default:
 		return;
 	}
@@ -179,12 +179,22 @@ static location_t parseGpsText(const QString &text)
 	return { {0}, {0} };
 }
 
+void LocationInformationWidget::diveSiteDeleted(struct dive_site *ds, int)
+{
+	// If the currently edited dive site was removed under our feet, close the widget.
+	// This will reset the dangling pointer.
+	if (ds && ds == diveSite)
+		acceptChanges();
+}
+
 void LocationInformationWidget::acceptChanges()
 {
+	diveSite = nullptr;
+	closeDistance = 0;
+
 	MainWindow::instance()->diveList->setEnabled(true);
 	MainWindow::instance()->setEnabledToolbar(true);
 	MainWindow::instance()->setApplicationState(ApplicationState::Default);
-	MapWidget::instance()->repopulateLabels();
 	MultiFilterSortModel::instance()->stopFilterDiveSites();
 }
 
