@@ -66,12 +66,6 @@ void MapWidget::centerOnIndex(const QModelIndex& idx)
 		centerOnDiveSite(ds);
 }
 
-void MapWidget::repopulateLabels()
-{
-	CHECK_IS_READY_RETURN_VOID();
-	m_mapHelper->reloadMapLocations();
-}
-
 void MapWidget::reload()
 {
 	CHECK_IS_READY_RETURN_VOID();
@@ -79,6 +73,24 @@ void MapWidget::reload()
 	m_mapHelper->centerOnSelectedDiveSite();
 }
 
+bool MapWidget::editMode() const
+{
+	return isReady && m_mapHelper->editMode();
+}
+
+void MapWidget::setSelected(const QVector<dive_site *> &divesites)
+{
+	CHECK_IS_READY_RETURN_VOID();
+	m_mapHelper->setSelected(divesites);
+}
+
+void MapWidget::selectionChanged()
+{
+	CHECK_IS_READY_RETURN_VOID();
+	m_mapHelper->selectionChanged();
+	m_mapHelper->centerOnSelectedDiveSite();
+}
+
 void MapWidget::selectedDivesChanged(const QList<int> &list)
 {
 	CHECK_IS_READY_RETURN_VOID();
