@@ -23,11 +23,13 @@ public:
 
 	static MapWidget *instance();
 	void reload();
+	void selectionChanged();
+	void setSelected(const QVector<dive_site *> &divesites);
+	bool editMode() const;
 
 public slots:
 	void centerOnDiveSite(struct dive_site *);
 	void centerOnIndex(const QModelIndex& idx);
-	void repopulateLabels();
 	void selectedDivesChanged(const QList<int> &);
 	void coordinatesChanged(struct dive_site *ds, const location_t &);
 	void doneLoading(QQuickWidget::Status status);
