@@ -1,4 +1,5 @@
 // SPDX-License-Identifier: GPL-2.0
+
 #include "desktop-widgets/modeldelegates.h"
 #include "core/subsurface-string.h"
 #include "core/gettextfromc.h"
@@ -13,6 +14,8 @@
 #include "qt-models/divetripmodel.h"
 #include "qt-models/divelocationmodel.h"
 #include "core/qthelper.h"
+#include "core/divesite.h"
+#include "desktop-widgets/simplewidgets.h"
 
 #include <QCompleter>
 #include <QKeyEvent>
@@ -22,6 +25,9 @@
 #include <QBrush>
 #include <QColor>
 #include <QAbstractProxyModel>
+#include <QLineEdit>
+#include <QAbstractItemView>
+#include <QSpinBox>
 
 QSize DiveListDelegate::sizeHint(const QStyleOptionViewItem&, const QModelIndex&) const
 {
@@ -47,7 +53,7 @@ void StarWidgetsDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 	if (!index.isValid())
 		return;
 
-	QVariant value = index.model()->data(index, DiveTripModel::STAR_ROLE);
+	QVariant value = index.model()->data(index, DiveTripModelBase::STAR_ROLE);
 	if (!value.isValid())
 		return;
 
@@ -97,7 +103,7 @@ void ComboBoxDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
 	c->lineEdit()->setSelection(0, c->lineEdit()->text().length());
 }
 
-struct CurrSelected {
+static struct CurrSelected {
 	QComboBox *comboEditor;
 	int currRow;
 	QString activeText;
@@ -227,7 +233,7 @@ void ComboBoxDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionV
 	editor->setGeometry(defaultRect);
 }
 
-struct RevertCylinderData {
+static struct RevertCylinderData {
 	QString type;
 	int pressure;
 	int size;
@@ -288,7 +294,7 @@ QWidget *TankInfoDelegate::createEditor(QWidget *parent, const QStyleOptionViewI
 	QWidget *delegate = ComboBoxDelegate::createEditor(parent, option, index);
 	CylindersModel *mymodel = qobject_cast<CylindersModel *>(currCombo.model);
 	cylinder_t *cyl = mymodel->cylinderAt(index);
-	currCylinderData.type = copy_string(cyl->type.description);
+	currCylinderData.type = cyl->type.description;
 	currCylinderData.pressure = cyl->type.workingpressure.mbar;
 	currCylinderData.size = cyl->type.size.mliter;
 	MainWindow::instance()->graphics->setReplot(false);
@@ -320,7 +326,7 @@ void TankUseDelegate::setModelData(QWidget * editor, QAbstractItemModel * model,
 	model->setData(index, comboBox->currentIndex());
 }
 
-struct RevertWeightData {
+static struct RevertWeightData {
 	QString type;
 	int weight;
 } currWeight;
@@ -366,7 +372,7 @@ QWidget *WSInfoDelegate::createEditor(QWidget *parent, const QStyleOptionViewIte
 	QWidget *editor = ComboBoxDelegate::createEditor(parent, option, index);
 	WeightModel *mymodel = qobject_cast<WeightModel *>(currCombo.model);
 	weightsystem_t *ws = mymodel->weightSystemAt(index);
-	currWeight.type = copy_string(ws->description);
+	currWeight.type = ws->description;
 	currWeight.weight = ws->weight.grams;
 	return editor;
 }
@@ -435,10 +441,15 @@ QWidget *DoubleSpinBoxDelegate::createEditor(QWidget *parent, const QStyleOption
 	return w;
 }
 
-LocationFilterDelegate::LocationFilterDelegate(QObject*)
+LocationFilterDelegate::LocationFilterDelegate(QObject *) : currentLocation({0, 0})
 {
 }
 
+void LocationFilterDelegate::setCurrentLocation(location_t loc)
+{
+	currentLocation = loc;
+}
+
 void LocationFilterDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &origIdx) const
 {
 	QFont fontBigger = qApp->font();
@@ -455,8 +466,7 @@ void LocationFilterDelegate::paint(QPainter *painter, const QStyleOptionViewItem
 	QIcon icon = index.data(Qt::DecorationRole).value<QIcon>();
 	struct dive_site *ds =
 		index.model()->data(index.model()->index(index.row(), LocationInformationModel::DIVESITE)).value<dive_site *>();
-	struct dive_site *currentDiveSite = current_dive ? get_dive_site_for_dive(current_dive) : nullptr;
-	bool currentDiveSiteHasGPS = currentDiveSite && dive_site_has_gps_location(currentDiveSite);
+	bool currentDiveHasGPS = has_location(&currentLocation);
 	//Special case: do not show name, but instead, show
 	if (index.row() < 2) {
 		diveSiteName = index.data().toString();
@@ -478,27 +488,24 @@ void LocationFilterDelegate::paint(QPainter *painter, const QStyleOptionViewItem
 		bottomText += QString(ds->taxonomy.category[idx].value);
 	}
 
-	if (bottomText.isEmpty()) {
-		const char *gpsCoords = printGPSCoords(&ds->location);
-		bottomText = QString(gpsCoords);
-		free( (void*) gpsCoords);
-	}
+	if (bottomText.isEmpty())
+		bottomText = printGPSCoords(&ds->location);
 
-	if (dive_site_has_gps_location(ds) && currentDiveSiteHasGPS) {
+	if (dive_site_has_gps_location(ds) && currentDiveHasGPS) {
 		// so we are showing a completion and both the current dive site and the completion
 		// have a GPS fix... so let's show the distance
-		if (same_location(&ds->location, &currentDiveSite->location)) {
+		if (same_location(&ds->location, &currentLocation)) {
 			bottomText += tr(" (same GPS fix)");
 		} else {
-			int distanceMeters = get_distance(&ds->location, &currentDiveSite->location);
+			int distanceMeters = get_distance(&ds->location, &currentLocation);
 			QString distance = distance_string(distanceMeters);
-			int nr = nr_of_dives_at_dive_site(ds, false);
+			int nr = nr_of_dives_at_dive_site(ds);
 			bottomText += tr(" (~%1 away").arg(distance);
 			bottomText += tr(", %n dive(s) here)", "", nr);
 		}
 	}
 	if (bottomText.isEmpty()) {
-		if (currentDiveSiteHasGPS)
+		if (currentDiveHasGPS)
 			bottomText = tr("(no existing GPS data, add GPS fix from this dive)");
 		else
 			bottomText = tr("(no GPS data)");
