@@ -20,10 +20,12 @@ public:
 	void showNotification(QString message, KMessageWidget::MessageType type);
 	void hideNotification();
 	QString getNotificationText();
-	~NotificationWidget();
 
+public
+slots:
+	void showError(QString message);
 private:
-	QFutureWatcher<void> *future_watcher;
+	QFutureWatcher<void> future_watcher;
 
 private
 slots:
