@@ -2,7 +2,7 @@
 #include "preferences_language.h"
 #include "ui_preferences_language.h"
 #include "core/qthelper.h"
-#include "core/subsurface-qt/SettingsObjectWrapper.h"
+#include "core/settings/qPrefLanguage.h"
 
 #include <QApplication>
 #include <QMessageBox>
@@ -81,16 +81,14 @@ void PreferencesLanguage::syncSettings()
 	if (languages.count())
 		currentLocale = m->data(languages.first(),Qt::UserRole).toString();
 
-
-	auto lang = SettingsObjectWrapper::instance()->language_settings;
-	lang->setLanguage(currentText);
-	lang->setLangLocale(currentLocale);
-	lang->setUseSystemLanguage(ui->languageSystemDefault->isChecked());
-	lang->setTimeFormatOverride(!ui->timeFormatSystemDefault->isChecked());
-	lang->setDateFormatOverride(!ui->dateFormatSystemDefault->isChecked());
-	lang->setTimeFormat(ui->timeFormatEntry->currentText());
-	lang->setDateFormat(ui->dateFormatEntry->currentText());
-	lang->setDateFormatShort(ui->shortDateFormatEntry->text());
+	qPrefLanguage::set_language(currentText);
+	qPrefLanguage::set_lang_locale(currentLocale);
+	qPrefLanguage::set_use_system_language(ui->languageSystemDefault->isChecked());
+	qPrefLanguage::set_time_format_override(!ui->timeFormatSystemDefault->isChecked());
+	qPrefLanguage::set_date_format_override(!ui->dateFormatSystemDefault->isChecked());
+	qPrefLanguage::set_time_format(ui->timeFormatEntry->currentText());
+	qPrefLanguage::set_date_format(ui->dateFormatEntry->currentText());
+	qPrefLanguage::set_date_format_short(ui->shortDateFormatEntry->text());
 	uiLanguage(NULL);
 
 	QString qDateTimeWeb = tr("These will be used as is. This might not be what you intended.\nSee http://doc.qt.io/qt-5/qdatetime.html#toString");
