@@ -3,7 +3,7 @@
 #include "ui_preferences_network.h"
 #include "subsurfacewebservices.h"
 #include "core/cloudstorage.h"
-#include "core/dive.h"
+#include "core/errorhelper.h"
 #include "core/settings/qPrefCloudStorage.h"
 #include "core/settings/qPrefProxy.h"
 #include <QNetworkProxy>
