@@ -2,7 +2,7 @@
 #include "preferences_units.h"
 #include "ui_preferences_units.h"
 #include "core/qthelper.h"
-#include "core/subsurface-qt/SettingsObjectWrapper.h"
+#include "core/settings/qPrefUnit.h"
 
 PreferencesUnits::PreferencesUnits(): AbstractPreferencesWidget(tr("Units"),QIcon(":units-icon"),1), ui(new Ui::PreferencesUnits())
 {
@@ -47,18 +47,17 @@ void PreferencesUnits::refreshSettings()
 
 void PreferencesUnits::syncSettings()
 {
-	auto units = SettingsObjectWrapper::instance()->unit_settings;
 	QString unitSystem[] = {"metric", "imperial", "personal"};
 	short unitValue = ui->metric->isChecked() ? METRIC : (ui->imperial->isChecked() ? IMPERIAL : PERSONALIZE);
 
-	units->setUnitSystem(unitSystem[unitValue]);
-	units->setTemperature(ui->fahrenheit->isChecked() ? units::FAHRENHEIT : units::CELSIUS);
-	units->setLength(ui->feet->isChecked() ? units::FEET : units::METERS);
-	units->setPressure(ui->psi->isChecked() ? units::PSI : units::BAR);
-	units->setVolume(ui->cuft->isChecked() ? units::CUFT : units::LITER);
-	units->setWeight(ui->lbs->isChecked() ? units::LBS : units::KG);
-	units->setVerticalSpeedTime(ui->vertical_speed_minutes->isChecked() ? units::MINUTES : units::SECONDS);
-	units->setCoordinatesTraditional(ui->gpsTraditional->isChecked());
-	units->setDurationUnits(ui->duration_mixed->isChecked() ? units::MIXED : (ui->duration_no_hours->isChecked() ? units::MINUTES_ONLY : units::ALWAYS_HOURS));
-	units->setShowUnitsTable(ui->show_units_table->isChecked());
+	qPrefUnits::set_unit_system(unitSystem[unitValue]);
+	qPrefUnits::set_temperature(ui->fahrenheit->isChecked() ? units::FAHRENHEIT : units::CELSIUS);
+	qPrefUnits::set_length(ui->feet->isChecked() ? units::FEET : units::METERS);
+	qPrefUnits::set_pressure(ui->psi->isChecked() ? units::PSI : units::BAR);
+	qPrefUnits::set_volume(ui->cuft->isChecked() ? units::CUFT : units::LITER);
+	qPrefUnits::set_weight(ui->lbs->isChecked() ? units::LBS : units::KG);
+	qPrefUnits::set_vertical_speed_time(ui->vertical_speed_minutes->isChecked() ? units::MINUTES : units::SECONDS);
+	qPrefUnits::set_coordinates_traditional(ui->gpsTraditional->isChecked());
+	qPrefUnits::set_duration_units(ui->duration_mixed->isChecked() ? units::MIXED : (ui->duration_no_hours->isChecked() ? units::MINUTES_ONLY : units::ALWAYS_HOURS));
+	qPrefUnits::set_show_units_table(ui->show_units_table->isChecked());
 }
