@@ -20,19 +20,17 @@ class FilterModelBase;
 #include "ui_urldialog.h"
 #include "ui_divecomponentselection.h"
 #include "ui_listfilter.h"
-#include "ui_filterwidget.h"
 #include "core/exif.h"
 #include "core/dive.h"
 
 
 class MinMaxAvgWidget : public QWidget {
 	Q_OBJECT
-	Q_PROPERTY(double minimum READ minimum WRITE setMinimum)
-	Q_PROPERTY(double maximum READ maximum WRITE setMaximum)
-	Q_PROPERTY(double average READ average WRITE setAverage)
+	QLabel *avgIco, *avgValue;
+	QLabel *minIco, *minValue;
+	QLabel *maxIco, *maxValue;
 public:
 	MinMaxAvgWidget(QWidget *parent);
-	~MinMaxAvgWidget();
 	double minimum() const;
 	double maximum() const;
 	double average() const;
@@ -45,11 +43,8 @@ public:
 	void overrideMinToolTipText(const QString &newTip);
 	void overrideAvgToolTipText(const QString &newTip);
 	void overrideMaxToolTipText(const QString &newTip);
-	void setAvgVisibility(const bool visible);
+	void setAvgVisibility(bool visible);
 	void clear();
-
-private:
-	QScopedPointer<MinMaxAvgWidgetPrivate> d;
 };
 
 class RenumberDialog : public QDialog {
@@ -150,59 +145,6 @@ private:
 	struct dive_components *what;
 };
 
-namespace Ui{
-	class FilterWidget2;
-};
-
-class MultiFilter : public QWidget {
-	Q_OBJECT
-public
-slots:
-	void closeFilter();
-	void adjustHeight();
-	void filterFinished();
-
-public:
-	MultiFilter(QWidget *parent);
-	Ui::FilterWidget2 ui;
-};
-
-class FilterBase : public QWidget {
-	Q_OBJECT
-	void addContextMenuEntry(const QString &s, void (FilterModelBase::*)());
-protected:
-	FilterBase(FilterModelBase *model, QWidget *parent = 0);
-	FilterModelBase *model;
-	Ui::FilterWidget ui;
-	void showEvent(QShowEvent *) override;
-	void hideEvent(QHideEvent *) override;
-	friend class MultiFilter;
-};
-
-class TagFilter : public FilterBase {
-	Q_OBJECT
-public:
-	TagFilter(QWidget *parent = 0);
-};
-
-class BuddyFilter : public FilterBase {
-	Q_OBJECT
-public:
-	BuddyFilter(QWidget *parent = 0);
-};
-
-class SuitFilter : public FilterBase {
-	Q_OBJECT
-public:
-	SuitFilter(QWidget *parent = 0);
-};
-
-class LocationFilter : public FilterBase {
-	Q_OBJECT
-public:
-	LocationFilter(QWidget *parent = 0);
-};
-
 class TextHyperlinkEventFilter : public QObject {
 	Q_OBJECT
 public:
