@@ -14,7 +14,7 @@ public:
 	explicit StarWidget(QWidget *parent = 0, Qt::WindowFlags f = 0);
 	int currentStars() const;
 
-	QSize sizeHint() const;
+	QSize sizeHint() const override;
 
 	static const QImage& starActive();
 	static const QImage& starInactive();
@@ -28,11 +28,11 @@ slots:
 	void setReadOnly(bool readOnly);
 
 protected:
-	void mouseReleaseEvent(QMouseEvent *);
-	void paintEvent(QPaintEvent *);
-	void focusInEvent(QFocusEvent *);
-	void focusOutEvent(QFocusEvent *);
-	void keyPressEvent(QKeyEvent *);
+	void mouseReleaseEvent(QMouseEvent *) override;
+	void paintEvent(QPaintEvent *) override;
+	void focusInEvent(QFocusEvent *) override;
+	void focusOutEvent(QFocusEvent *) override;
+	void keyPressEvent(QKeyEvent *) override;
 
 private:
 	int current;
