@@ -13,7 +13,7 @@ public:
 	YearlyStatisticsWidget(QWidget *parent = 0);
 	void setModel(YearlyStatisticsModel *m);
 protected:
-	void resizeEvent(QResizeEvent *event);
+	void resizeEvent(QResizeEvent *event) override;
 public slots:
 	void modelRowsInserted(const QModelIndex& index, int first, int last);
 	void modelDataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight);
