@@ -21,9 +21,9 @@ TabDiveStatistics::TabDiveStatistics(QWidget *parent) : TabBase(parent), ui(new
 	ui->timeLimits->overrideMinToolTipText(tr("Shortest dive"));
 	ui->timeLimits->overrideAvgToolTipText(tr("Average length of all selected dives"));
 
-	Q_FOREACH (QObject *obj, children()) {
-		if (QLabel *label = qobject_cast<QLabel *>(obj))
-			label->setAlignment(Qt::AlignHCenter);
+	const auto l = findChildren<QLabel *>(QString(), Qt::FindDirectChildrenOnly);
+	for (QLabel *label: l) {
+		label->setAlignment(Qt::AlignHCenter);
 	}
 }
 
@@ -48,17 +48,13 @@ void TabDiveStatistics::updateData()
 	calculate_stats_selected(&stats_selection);
 	clear();
 	ui->depthLimits->setMaximum(get_depth_string(stats_selection.max_depth, true));
-	if (amount_selected > 1)
+	if (amount_selected > 1) {
 		ui->depthLimits->setMinimum(get_depth_string(stats_selection.min_depth, true));
-	else
+		ui->depthLimits->setAverage(get_depth_string(stats_selection.combined_max_depth.mm / stats_selection.selection_size, true));
+	} else {
 		ui->depthLimits->setMinimum("");
-	// the overall average depth is really confusing when listed between the
-	// deepest and shallowest dive - let's just not set it
-	// ui->depthLimits->setAverage(get_depth_string(stats_selection.avg_depth, true));
-
-	// Also hide the avgIco, so its clear that its not there.
-	ui->depthLimits->overrideAvgToolTipText("");
-	ui->depthLimits->setAvgVisibility(false);
+		ui->depthLimits->setAverage("");
+	}
 
 	if (stats_selection.max_sac.mliter && (stats_selection.max_sac.mliter != stats_selection.avg_sac.mliter))
 		ui->sacLimits->setMaximum(get_volume_string(stats_selection.max_sac, true).append(tr("/min")));
@@ -101,10 +97,9 @@ void TabDiveStatistics::updateData()
 		ui->timeLimits->setMinimum("");
 	}
 
-	QVector<QPair<QString, int> > gasUsed;
+	QVector<QPair<QString, int> > gasUsed = selectedDivesGasUsed();
 	QString gasUsedString;
 	volume_t vol;
-	selectedDivesGasUsed(gasUsed);
 	for (int j = 0; j < MAX_CYLINDERS; j++) {
 		if (gasUsed.isEmpty())
 			break;
