@@ -70,7 +70,8 @@ void TagWidget::highlight()
 {
 	removeAllBlocks();
 	int lastPos = 0;
-	Q_FOREACH (const QString& s, text().split(QChar(','), QString::SkipEmptyParts)) {
+	const auto l = text().split(QChar(','), QString::SkipEmptyParts);
+	for (const QString &s: l) {
 		QString trimmed = s.trimmed();
 		if (trimmed.isEmpty())
 			continue;
@@ -88,14 +89,6 @@ void TagWidget::reparse()
 	if (pos.first >= 0 && pos.second > 0)
 		currentText = text().mid(pos.first, pos.second - pos.first).trimmed();
 
-	/*
-	 * Do not show the completer when not in edit mode - basically
-	 * this returns when we are accepting or discarding the changes.
-	 */
-	if (MainWindow::instance()->mainTab->isEditing() == false) {
-		return;
-	}
-
 	if (m_completer) {
 		m_completer->setCompletionPrefix(currentText);
 		if (m_completer->completionCount() == 1) {
@@ -210,3 +203,11 @@ void TagWidget::fixPopupPosition(int delta)
 		m_completer->popup()->setGeometry(toGlobal.x(), toGlobal.y() + delta +10, toGlobal.width(), toGlobal.height());
 	}
 }
+
+// Since we capture enter / return / tab, we never send an editingFinished() signal.
+// Therefore, override the focusOutEvent()
+void TagWidget::focusOutEvent(QFocusEvent *ev)
+{
+	GroupedLineEdit::focusOutEvent(ev);
+	emit editingFinished();
+}
