@@ -11,6 +11,7 @@
 #include "qt-models/divelocationmodel.h"
 #ifndef SUBSURFACE_MOBILE
 #include "qt-models/filtermodels.h"
+#include "desktop-widgets/mapwidget.h"
 #endif
 
 #define SMALL_CIRCLE_RADIUS_PX            26.0
@@ -21,8 +22,6 @@ MapWidgetHelper::MapWidgetHelper(QObject *parent) : QObject(parent)
 	m_smallCircleRadius = SMALL_CIRCLE_RADIUS_PX;
 	m_map = nullptr;
 	m_editMode = false;
-	connect(m_mapLocationModel, SIGNAL(selectedLocationChanged(MapLocation *)),
-	        this, SLOT(selectedLocationChanged(MapLocation *)));
 	connect(&diveListNotifier, &DiveListNotifier::diveSiteChanged, this, &MapWidgetHelper::diveSiteChanged);
 }
 
@@ -37,16 +36,21 @@ void MapWidgetHelper::centerOnDiveSite(struct dive_site *ds)
 {
 	if (!dive_site_has_gps_location(ds)) {
 		// dive site with no GPS
-		m_mapLocationModel->setSelected(ds, false);
+		m_mapLocationModel->setSelected(ds);
 		QMetaObject::invokeMethod(m_map, "deselectMapLocation");
 	} else {
 		// dive site with GPS
-		m_mapLocationModel->setSelected(ds, false);
+		m_mapLocationModel->setSelected(ds);
 		QGeoCoordinate dsCoord (ds->location.lat.udeg * 0.000001, ds->location.lon.udeg * 0.000001);
 		QMetaObject::invokeMethod(m_map, "centerOnCoordinate", Q_ARG(QVariant, QVariant::fromValue(dsCoord)));
 	}
 }
 
+void MapWidgetHelper::setSelected(const QVector<dive_site *> &divesites)
+{
+	m_mapLocationModel->setSelected(divesites);
+}
+
 void MapWidgetHelper::centerOnSelectedDiveSite()
 {
 	QVector<struct dive_site *> selDS = m_mapLocationModel->selectedDs();
@@ -96,25 +100,43 @@ void MapWidgetHelper::centerOnSelectedDiveSite()
 	}
 }
 
-void MapWidgetHelper::reloadMapLocations()
+void MapWidgetHelper::updateEditMode()
 {
 #ifndef SUBSURFACE_MOBILE
 	// The filter being set to dive site is the signal that we are in dive site edit mode.
 	// This is the case when either the dive site edit tab or the dive site list tab are active.
-	if (MultiFilterSortModel::instance()->diveSiteMode())
-		enterEditMode();
-	else
-		exitEditMode();
+	bool old = m_editMode;
+	m_editMode = MultiFilterSortModel::instance()->diveSiteMode();
+	if (old != m_editMode)
+		emit editModeChanged();
 #endif
+}
+
+void MapWidgetHelper::reloadMapLocations()
+{
+	updateEditMode();
 	m_mapLocationModel->reload(m_map);
 }
 
-void MapWidgetHelper::selectedLocationChanged(MapLocation *location)
+void MapWidgetHelper::selectionChanged()
+{
+	updateEditMode();
+	m_mapLocationModel->selectionChanged();
+}
+
+void MapWidgetHelper::selectedLocationChanged(struct dive_site *ds_in)
 {
 	int idx;
 	struct dive *dive;
 	QList<int> selectedDiveIds;
-	QGeoCoordinate locationCoord = location->coordinate();
+
+	if (!ds_in)
+		return;
+	MapLocation *location = m_mapLocationModel->getMapLocation(ds_in);
+	if (!location)
+		return;
+	QGeoCoordinate locationCoord = location->coordinate;
+
 	for_each_dive (idx, dive) {
 		struct dive_site *ds = get_dive_site_for_dive(dive);
 		if (!dive_site_has_gps_location(ds))
@@ -127,7 +149,7 @@ void MapWidgetHelper::selectedLocationChanged(MapLocation *location)
 			selectedDiveIds.append(idx);
 	}
 #else // the mobile version doesn't support multi-dive selection
-		if (ds == location->divesite())
+		if (ds == location->divesite)
 			selectedDiveIds.append(dive->id); // use id here instead of index
 	}
 	int last; // get latest dive chronologically
@@ -215,7 +237,7 @@ void MapWidgetHelper::updateCurrentDiveSiteCoordinatesFromMap(struct dive_site *
 {
 	MapLocation *loc = m_mapLocationModel->getMapLocation(ds);
 	if (loc)
-		loc->setCoordinate(coord);
+		loc->coordinate = coord;
 	location_t location = mk_location(coord);
 	emit coordinatesChanged(ds, location);
 }
@@ -225,21 +247,9 @@ void MapWidgetHelper::diveSiteChanged(struct dive_site *ds, int field)
 	centerOnDiveSite(ds);
 }
 
-void MapWidgetHelper::exitEditMode()
+bool MapWidgetHelper::editMode() const
 {
-	if (!m_editMode)
-		return;
-	m_editMode = false;
-	emit editModeChanged();
-}
-
-void MapWidgetHelper::enterEditMode()
-{
-	if (m_editMode)
-		return;
-
-	m_editMode = true;
-	emit editModeChanged();
+	return m_editMode;
 }
 
 QString MapWidgetHelper::pluginObject()
