@@ -35,18 +35,20 @@ public:
 	Q_INVOKABLE void calculateSmallCircleRadius(QGeoCoordinate coord);
 	Q_INVOKABLE void updateCurrentDiveSiteCoordinatesFromMap(struct dive_site *ds, QGeoCoordinate coord);
 	Q_INVOKABLE void selectVisibleLocations();
+	Q_INVOKABLE void selectedLocationChanged(struct dive_site *ds);
+	void selectionChanged();
+	void setSelected(const QVector<dive_site *> &divesites);
 	QString pluginObject();
+	bool editMode() const;
 
 private:
-	void enterEditMode();
-	void exitEditMode();
+	void updateEditMode();
 	QObject *m_map;
 	MapLocationModel *m_mapLocationModel;
 	qreal m_smallCircleRadius;
 	bool m_editMode;
 
 private slots:
-	void selectedLocationChanged(MapLocation *);
 	void diveSiteChanged(struct dive_site *ds, int field);
 
 signals:
