@@ -26,6 +26,7 @@
 #include "qt-models/messagehandlermodel.h"
 #include "qt-models/tankinfomodel.h"
 #include "core/device.h"
+#include "core/errorhelper.h"
 #include "core/file.h"
 #include "core/qthelper.h"
 #include "core/qt-gui.h"
@@ -332,13 +333,19 @@ void QMLManager::openLocalThenRemote(QString url)
 	updateAllGlobalLists();
 }
 
+void QMLManager::updateSiteList()
+{
+	LocationInformationModel::instance()->update();
+	emit locationListChanged();
+}
+
 void QMLManager::updateAllGlobalLists()
 {
 	buddyModel.updateModel(); emit buddyListChanged();
 	suitModel.updateModel(); emit suitListChanged();
 	divemasterModel.updateModel(); emit divemasterListChanged();
 	// TODO: Probably not needed anymore, as the dive site list is generated on the fly!
-	LocationInformationModel::instance()->update(); emit locationListChanged();
+	updateSiteList();
 }
 
 void QMLManager::mergeLocalRepo()
@@ -480,7 +487,7 @@ void QMLManager::saveCloudCredentials()
 	}
 
 	cloudCredentialsChanged |= !same_string(prefs.cloud_storage_password,
-								qPrintable(QMLPrefs::instance()->cloudPassword()));
+						qPrintable(QMLPrefs::instance()->cloudPassword()));
 
 	if (QMLPrefs::instance()->credentialStatus() != qPrefCloudStorage::CS_NOCLOUD &&
 		!cloudCredentialsChanged) {
@@ -773,7 +780,7 @@ void QMLManager::refreshDiveList()
 	DiveListModel::instance()->addAllDives();
 }
 
-static void setupDivesite(struct dive *d, struct dive_site *ds, double lat, double lon, const char *locationtext)
+void QMLManager::setupDivesite(struct dive *d, struct dive_site *ds, double lat, double lon, const char *locationtext)
 {
 	location_t location = create_location(lat, lon);
 	if (ds) {
@@ -781,6 +788,8 @@ static void setupDivesite(struct dive *d, struct dive_site *ds, double lat, doub
 	} else {
 		unregister_dive_from_dive_site(d);
 		add_dive_to_dive_site(d, create_dive_site_with_gps(locationtext, &location, &dive_site_table));
+		// We created a new dive site - let the dive site model know.
+		updateSiteList();
 	}
 }
 
@@ -901,6 +910,8 @@ bool QMLManager::checkLocation(DiveObjectHelper *myDive, struct dive *d, QString
 			ds = create_dive_site(qPrintable(location), &dive_site_table);
 		unregister_dive_from_dive_site(d);
 		add_dive_to_dive_site(d, ds);
+		// We created a new dive site - let the dive site model know.
+		updateSiteList();
 	}
 	// now make sure that the GPS coordinates match - if the user changed the name but not
 	// the GPS coordinates, this still does the right thing as the now new dive site will
@@ -1029,11 +1040,14 @@ void QMLManager::commitChanges(QString diveId, QString date, QString location, Q
 		diveChanged = true;
 		d->watertemp.mkelvin = parseTemperatureToMkelvin(watertemp);
 	}
-	// not sure what we'd do if there was more than one weight system
-	// defined - for now just ignore that case
-	if (d->weightsystems.nr == 1) {
-		if (myDive->sumWeight() != weight) {
-			diveChanged = true;
+	if (myDive->sumWeight() != weight) {
+		diveChanged = true;
+		// not sure what we'd do if there was more than one weight system
+		// defined - for now just ignore that case
+		if (d->weightsystems.nr == 0) {
+			weightsystem_t ws = { { parseWeightToGrams(weight) } , strdup(qPrintable(tr("weight"))) };
+			add_to_weightsystem_table(&d->weightsystems, 0, ws); // takes ownership of the string
+		} else if (d->weightsystems.nr == 1) {
 			d->weightsystems.weightsystems[0].weight.grams = parseWeightToGrams(weight);
 		}
 	}
