@@ -3,7 +3,8 @@
 #define QMLPREFS_H
 
 #include <QObject>
-#include "core/settings/qPref.h"
+#include "core/settings/qPrefCloudStorage.h"
+#include "core/settings/qPrefDisplay.h"
 
 
 class QMLPrefs : public QObject {
@@ -20,35 +21,18 @@ class QMLPrefs : public QObject {
 				MEMBER m_cloudUserName
 				WRITE setCloudUserName
 				NOTIFY cloudUserNameChanged)
-	Q_PROPERTY(qPref::cloud_status credentialStatus
+	Q_PROPERTY(qPrefCloudStorage::cloud_status credentialStatus
 				MEMBER m_credentialStatus
 				WRITE setCredentialStatus
 				NOTIFY credentialStatusChanged)
-	Q_PROPERTY(bool developer
-				MEMBER m_developer
-				WRITE setDeveloper
-				NOTIFY developerChanged)
-	Q_PROPERTY(int distanceThreshold
-				MEMBER m_distanceThreshold
-				WRITE setDistanceThreshold
-				NOTIFY distanceThresholdChanged)
 	Q_PROPERTY(bool showPin
 				MEMBER m_showPin
 				WRITE setShowPin
 				NOTIFY showPinChanged)
-	Q_PROPERTY(qPref::cloud_status oldStatus
+	Q_PROPERTY(qPrefCloudStorage::cloud_status oldStatus
 				MEMBER m_oldStatus
 				WRITE setOldStatus
 				NOTIFY oldStatusChanged)
-	Q_PROPERTY(QString theme
-				READ theme
-				WRITE setTheme
-				NOTIFY themeChanged)
-	Q_PROPERTY(int timeThreshold
-				MEMBER m_timeThreshold
-				WRITE setTimeThreshold
-				NOTIFY timeThresholdChanged)
-
 public:
 	QMLPrefs();
 	~QMLPrefs();
@@ -64,26 +48,15 @@ public:
 	const QString cloudUserName() const;
 	void setCloudUserName(const QString &cloudUserName);
 
-	qPref::cloud_status credentialStatus() const;
-	void setCredentialStatus(const qPref::cloud_status value);
+	qPrefCloudStorage::cloud_status credentialStatus() const;
+	void setCredentialStatus(const qPrefCloudStorage::cloud_status value);
 
-	void setDeveloper(bool value);
-
-	int distanceThreshold() const;
-	void setDistanceThreshold(int distance);
-
-	qPref::cloud_status oldStatus() const;
-	void setOldStatus(const qPref::cloud_status value);
+	qPrefCloudStorage::cloud_status oldStatus() const;
+	void setOldStatus(const qPrefCloudStorage::cloud_status value);
 
 	bool showPin() const;
 	void setShowPin(bool enable);
 
-	int  timeThreshold() const;
-	void setTimeThreshold(int time);
-
-	const QString theme() const;
-	void setTheme(QString theme);
-
 public slots:
 	void cancelCredentialsPinSetup();
 	void clearCredentials();
@@ -92,25 +65,18 @@ private:
 	QString m_cloudPassword;
 	QString m_cloudPin;
 	QString m_cloudUserName;
-	qPref::cloud_status m_credentialStatus;
-	bool m_developer;
-	int m_distanceThreshold;
+	qPrefCloudStorage::cloud_status m_credentialStatus;
 	static QMLPrefs *m_instance;
-	qPref::cloud_status m_oldStatus;
+	qPrefCloudStorage::cloud_status m_oldStatus;
 	bool m_showPin;
-	int m_timeThreshold;
 
 signals:
 	void cloudPasswordChanged();
 	void cloudPinChanged();
 	void cloudUserNameChanged();
 	void credentialStatusChanged();
-	void distanceThresholdChanged();
-	void developerChanged();
 	void oldStatusChanged();
 	void showPinChanged();
-	void themeChanged();
-	void timeThresholdChanged();
 };
 
 #endif
