@@ -149,16 +149,22 @@ echo "${BUILDNR}" > ./buildnr.dat
 
 echo "Building Subsurface-mobile for Android, build nr ${BUILDNR}"
 
-rm -f ./subsurface-mobile-build-arm/build/outputs/apk/*.apk
+rm -f ./subsurface-mobile-build-arm/build/outputs/apk/debug/*.apk
 rm -df ./subsurface-mobile-build-arm/AndroidManifest.xml
 
 if [ "$USE_X" ] ; then
 	bash "$USE_X" "$SUBSURFACE_SOURCE"/packaging/android/build.sh -buildnr "$BUILDNR" arm "$@"
+	# the arm64 APK has to have a higher build number
+	BUILDNR=$((BUILDNR+1))
+	echo "${BUILDNR}" > ./buildnr.dat
 	bash "$USE_X" "$SUBSURFACE_SOURCE"/packaging/android/build.sh -buildnr "$BUILDNR" arm64 "$@"
 else
 	bash "$SUBSURFACE_SOURCE"/packaging/android/build.sh -buildnr "$BUILDNR" arm "$@"
+	# the arm64 APK has to have a higher build number
+	BUILDNR=$((BUILDNR+1))
+	echo "${BUILDNR}" > ./buildnr.dat
 	bash "$SUBSURFACE_SOURCE"/packaging/android/build.sh -buildnr "$BUILDNR" arm64 "$@"
 fi
 
-ls -l ./subsurface-mobile-build-arm/build/outputs/apk/*.apk
+ls -l ./subsurface-mobile-build-arm/build/outputs/apk/debug/*.apk
 
