@@ -10,6 +10,8 @@
 #include "core/membuffer.h"
 #include "core/subsurface-string.h"
 
+#define DEPTH_NOT_FOUND (-2342)
+
 extern struct ev_select *ev_namelist;
 extern int evn_used;
 
@@ -30,20 +32,21 @@ DiveEventItem::~DiveEventItem()
 void DiveEventItem::setHorizontalAxis(DiveCartesianAxis *axis)
 {
 	hAxis = axis;
-	recalculatePos(true);
+	recalculatePos(0);
 }
 
 void DiveEventItem::setModel(DivePlotDataModel *model)
 {
 	dataModel = model;
-	recalculatePos(true);
+	recalculatePos(0);
 }
 
-void DiveEventItem::setVerticalAxis(DiveCartesianAxis *axis)
+void DiveEventItem::setVerticalAxis(DiveCartesianAxis *axis, int speed)
 {
 	vAxis = axis;
-	recalculatePos(true);
-	connect(vAxis, SIGNAL(sizeChanged()), this, SLOT(recalculatePos()));
+	recalculatePos(0);
+	connect(vAxis, &DiveCartesianAxis::sizeChanged, this,
+		[speed, this] { recalculatePos(speed); });
 }
 
 struct event *DiveEventItem::getEvent()
@@ -60,7 +63,7 @@ void DiveEventItem::setEvent(struct event *ev, struct gasmix lastgasmix)
 	internalEvent = clone_event(ev);
 	setupPixmap(lastgasmix);
 	setupToolTipString(lastgasmix);
-	recalculatePos(true);
+	recalculatePos(0);
 }
 
 void DiveEventItem::setupPixmap(struct gasmix lastgasmix)
@@ -234,7 +237,8 @@ bool DiveEventItem::shouldBeHidden()
 	struct sample *first_sample = &dc->sample[0];
 	if (!strcmp(event->name, "gaschange") &&
 	    (event->time.seconds == 0 ||
-	     (first_sample && event->time.seconds == first_sample->time.seconds)))
+	     (first_sample && event->time.seconds == first_sample->time.seconds) ||
+	     depthAtTime(event->time.seconds) < SURFACE_THRESHOLD))
 		return true;
 
 	/*
@@ -254,7 +258,18 @@ bool DiveEventItem::shouldBeHidden()
 	return false;
 }
 
-void DiveEventItem::recalculatePos(bool instant)
+int DiveEventItem::depthAtTime(int time)
+{
+	QModelIndexList result = dataModel->match(dataModel->index(0, DivePlotDataModel::TIME), Qt::DisplayRole, time);
+	if (result.isEmpty()) {
+		Q_ASSERT("can't find a spot in the dataModel");
+		hide();
+		return DEPTH_NOT_FOUND;
+	}
+	return dataModel->data(dataModel->index(result.first().row(), DivePlotDataModel::DEPTH)).toInt();
+}
+
+void DiveEventItem::recalculatePos(int speed)
 {
 	if (!vAxis || !hAxis || !internalEvent || !dataModel)
 		return;
@@ -265,13 +280,15 @@ void DiveEventItem::recalculatePos(bool instant)
 		hide();
 		return;
 	}
+	int depth = depthAtTime(internalEvent->time.seconds);
+	if (depth == DEPTH_NOT_FOUND)
+		return;
 	if (!isVisible() && !shouldBeHidden())
 		show();
-	int depth = dataModel->data(dataModel->index(result.first().row(), DivePlotDataModel::DEPTH)).toInt();
 	qreal x = hAxis->posAtValue(internalEvent->time.seconds);
 	qreal y = vAxis->posAtValue(depth);
-	if (!instant)
-		Animations::moveTo(this, x, y);
+	if (speed > 0)
+		Animations::moveTo(this, speed, x, y);
 	else
 		setPos(x, y);
 	if (isVisible() && shouldBeHidden())
