@@ -75,7 +75,7 @@ public:
 	ProfileWidget2(QWidget *parent = 0);
 	void resetZoom();
 	void scale(qreal sx, qreal sy);
-	void plotDive(const struct dive *d = 0, bool force = false, bool clearPictures = false, bool plotPicturesSynchronously = false);
+	void plotDive(const struct dive *d = 0, bool force = false, bool clearPictures = false, bool instant = false);
 	void setupItem(AbstractProfilePolygonItem *item, DiveCartesianAxis *vAxis, int vData, int hData, int zValue);
 	void setPrintMode(bool mode, bool grayscale = false);
 	bool getPrintMode();
@@ -90,6 +90,7 @@ public:
 	void recalcCeiling();
 	void setToolTipVisibile(bool visible);
 	State currentState;
+	int animSpeed;
 
 signals:
 	void fontPrintScaleChanged(double scale);
@@ -97,7 +98,7 @@ signals:
 	void enableShortcuts();
 	void disableShortcuts(bool paste);
 	void refreshDisplay(bool recreateDivelist);
-	void updateDiveInfo(bool clear);
+	void updateDiveInfo();
 	void editCurrentDive();
 	void dateTimeChangedItems();
 
@@ -126,6 +127,7 @@ slots: // Necessary to call from QAction's signals.
 	void editName();
 	void makeFirstDC();
 	void deleteCurrentDC();
+	void splitCurrentDC();
 	void pointInserted(const QModelIndex &parent, int start, int end);
 	void pointsRemoved(const QModelIndex &, int start, int end);
 	void updateThumbnail(QString filename, QImage thumbnail, duration_t duration);
