@@ -2,6 +2,24 @@
 #include "cleanertablemodel.h"
 #include "core/metrics.h"
 
+const QPixmap &trashIcon()
+{
+	static QPixmap trash = QPixmap(":list-remove-icon").scaledToHeight(defaultIconMetrics().sz_small);
+	return trash;
+}
+
+const QPixmap &trashForbiddenIcon()
+{
+	static QPixmap trash = QPixmap(":list-remove-disabled-icon").scaledToHeight(defaultIconMetrics().sz_small);
+	return trash;
+}
+
+const QPixmap &editIcon()
+{
+	static QPixmap edit = QPixmap(":edit-icon").scaledToHeight(defaultIconMetrics().sz_small);
+	return edit;
+}
+
 CleanerTableModel::CleanerTableModel(QObject *parent) : QAbstractTableModel(parent)
 {
 }
@@ -13,19 +31,16 @@ int CleanerTableModel::columnCount(const QModelIndex&) const
 
 QVariant CleanerTableModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-	QVariant ret;
-
 	if (orientation == Qt::Vertical)
-		return ret;
+		return QVariant();
 
 	switch (role) {
 	case Qt::FontRole:
-		ret = defaultModelFont();
-		break;
+		return defaultModelFont();
 	case Qt::DisplayRole:
-		ret = headers.at(section);
+		return headers.at(section);
 	}
-	return ret;
+	return QVariant();
 }
 
 void CleanerTableModel::setHeaderDataStrings(const QStringList &newHeaders)
