@@ -426,7 +426,7 @@ void CylindersModel::add()
 	}
 
 	int row = rows;
-	fill_default_cylinder(&displayed_dive.cylinder[row]);
+	fill_default_cylinder(&displayed_dive, row);
 	displayed_dive.cylinder[row].start = displayed_dive.cylinder[row].type.workingpressure;
 	displayed_dive.cylinder[row].manually_added = true;
 	displayed_dive.cylinder[row].cylinder_use = OC_GAS;
