@@ -13,8 +13,8 @@ public:
 		VALUE
 	};
 	explicit ExtraDataModel(QObject *parent = 0);
-	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-	int rowCount(const QModelIndex &parent = QModelIndex()) const;
+	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+	int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
 	void clear();
 	void updateDive();
