@@ -165,7 +165,7 @@ void DivePlannerPointsModel::setupCylinders()
 				return;		// We have at least one cylinder
 	}
 	if (!empty_string(prefs.default_cylinder)) {
-		fill_default_cylinder(&displayed_dive.cylinder[0]);
+		fill_default_cylinder(&displayed_dive, 0);
 		displayed_dive.cylinder[0].start = displayed_dive.cylinder[0].type.workingpressure;
 	}
 	if (cylinder_none(&displayed_dive.cylinder[0])) {
