@@ -5,14 +5,16 @@
 #if !defined(Q_OS_ANDROID)
 #define INFO(fmt, ...)	fprintf(stderr, "INFO: " fmt "\n", ##__VA_ARGS__)
 #else
-extern void writeToAppLogFile(QString logText);
 #include <android/log.h>
 #define INFO(fmt, ...)	__android_log_print(ANDROID_LOG_DEBUG, __FILE__, "INFO: " fmt "\n", ##__VA_ARGS__);
 #endif
 
-void logMessageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
+extern void writeToAppLogFile(QString logText);
+#endif
+
+void logMessageHandler(QtMsgType type, const QMessageLogContext&, const QString &msg)
 {
-	Q_UNUSED(context)
 	MessageHandlerModel::self()->addLog(type, msg);
 }
 
@@ -22,16 +24,14 @@ MessageHandlerModel * MessageHandlerModel::self()
 	return self;
 }
 
-MessageHandlerModel::MessageHandlerModel(QObject *parent)
+MessageHandlerModel::MessageHandlerModel(QObject*)
 {
-	Q_UNUSED(parent)
 	// no more than one message handler.
 	qInstallMessageHandler(logMessageHandler);
 }
 
-int MessageHandlerModel::rowCount(const QModelIndex& parent) const
+int MessageHandlerModel::rowCount(const QModelIndex&) const
 {
-	Q_UNUSED(parent)
 	return m_data.size();
 }
 
@@ -43,11 +43,20 @@ void MessageHandlerModel::addLog(QtMsgType type, const QString& message)
 	m_data.append({message, type});
 	endInsertRows();
 	INFO("%s", qPrintable(message));
-#if defined (Q_OS_ANDROID)
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
 	writeToAppLogFile(message);
 #endif
 }
 
+const QString MessageHandlerModel::logAsString()
+{
+	QString copyString;
+
+	// Loop through m_data and build big string to be put on the clipboard
+	for(const MessageData &data: m_data)
+		copyString += data.message + "\n";
+	return copyString;
+}
 QVariant MessageHandlerModel::data(const QModelIndex& idx, int role) const
 {
 	switch(role) {
