@@ -15,6 +15,7 @@ public:
 		SHORTEST_TIME,
 		LONGEST_TIME,
 		AVG_DEPTH,
+		AVG_MAX_DEPTH,
 		MIN_DEPTH,
 		MAX_DEPTH,
 		AVG_SAC,
@@ -27,13 +28,13 @@ public:
 	};
 
 	QVariant data(int column, int role) const;
-	YearStatisticsItem(stats_t interval);
+	YearStatisticsItem(const stats_t &interval);
 
 private:
 	stats_t stats_interval;
 };
 
-YearStatisticsItem::YearStatisticsItem(stats_t interval) : stats_interval(interval)
+YearStatisticsItem::YearStatisticsItem(const stats_t &interval) : stats_interval(interval)
 {
 }
 
@@ -74,6 +75,10 @@ QVariant YearStatisticsItem::data(int column, int role) const
 	case AVG_DEPTH:
 		ret = get_depth_string(stats_interval.avg_depth);
 		break;
+	case AVG_MAX_DEPTH:
+		if (stats_interval.selection_size)
+			ret = get_depth_string(stats_interval.combined_max_depth.mm / stats_interval.selection_size);
+		break;
 	case MIN_DEPTH:
 		ret = get_depth_string(stats_interval.min_depth);
 		break;
@@ -143,6 +148,9 @@ QVariant YearlyStatisticsModel::headerData(int section, Qt::Orientation orientat
 		case AVG_DEPTH:
 			val = QString(tr("Depth (%1)\n Average")).arg(get_depth_unit());
 			break;
+		case AVG_MAX_DEPTH:
+			val = tr("\nAverage maximum");
+			break;
 		case MIN_DEPTH:
 			val = tr("\nMinimum");
 			break;
@@ -177,6 +185,8 @@ void YearlyStatisticsModel::update_yearly_stats()
 	int i, month = 0;
 	unsigned int j, combined_months;
 	stats_summary_auto_free stats;
+	QString label;
+	temperature_t t_range_min,t_range_max;
 	calculate_stats_summary(&stats, false);
 
 	for (i = 0; stats.stats_yearly != NULL && stats.stats_yearly[i].period; ++i) {
@@ -217,4 +227,38 @@ void YearlyStatisticsModel::update_yearly_stats()
 		rootItem->children.append(item);
 		item->parent = rootItem.get();
 	}
+
+	/* Show the statistic sorted by dive depth */
+	if (stats.stats_by_depth != NULL && stats.stats_by_depth[0].selection_size) {
+		YearStatisticsItem *item = new YearStatisticsItem(stats.stats_by_depth[0]);
+		for (i = 1; stats.stats_by_depth[i].is_trip; ++i)
+			if (stats.stats_by_depth[i].selection_size) {
+				label = QString(tr("%1 - %2")).arg(get_depth_string((i - 1) * (STATS_DEPTH_BUCKET * 1000), true, false),
+					get_depth_string(i * (STATS_DEPTH_BUCKET * 1000), true, false));
+				stats.stats_by_depth[i].location = strdup(label.toUtf8().data());
+				YearStatisticsItem *iChild = new YearStatisticsItem(stats.stats_by_depth[i]);
+				item->children.append(iChild);
+				iChild->parent = item;
+			}
+		rootItem->children.append(item);
+		item->parent = rootItem.get();
+	}
+
+	/* Show the statistic sorted by dive temperature */
+	if (stats.stats_by_temp != NULL && stats.stats_by_temp[0].selection_size) {
+		YearStatisticsItem *item = new YearStatisticsItem(stats.stats_by_temp[0]);
+		for (i = 1; stats.stats_by_temp[i].is_trip; ++i)
+			if (stats.stats_by_temp[i].selection_size) {
+				t_range_min.mkelvin = C_to_mkelvin((i - 1) * STATS_TEMP_BUCKET);
+				t_range_max.mkelvin = C_to_mkelvin(i * STATS_TEMP_BUCKET);
+				label = QString(tr("%1 - %2")).arg(get_temperature_string(t_range_min, true),
+					get_temperature_string(t_range_max, true));
+				stats.stats_by_temp[i].location = strdup(label.toUtf8().data());
+				YearStatisticsItem *iChild = new YearStatisticsItem(stats.stats_by_temp[i]);
+				item->children.append(iChild);
+				iChild->parent = item;
+			}
+		rootItem->children.append(item);
+		item->parent = rootItem.get();
+	}
 }
