@@ -8,4 +8,4 @@ set -e
 # (but of course having the right things in place will save a ton of time)
 docker exec -e TRAVIS="$TRAVIS" -t android-builder subsurface/packaging/android/android-build-wrapper.sh
 
-ls -l ../subsurface-mobile-build-docker-arm*/build/outputs/apk/
+ls -l ../subsurface-mobile-build-docker-arm*/build/outputs/apk/debug
