@@ -26,3 +26,8 @@ sudo ln -s $QT_ROOT /usr/local/Qt-5.9.3
 export DISPLAY=:99.0
 sh -e /etc/init.d/xvfb start
 
+# TestParsePerformance needs this data file to test XML parsing performance
+pushd ..
+git clone https://github.com/Subsurface-divelog/large-anonymous-sample-data
+xzcat large-anonymous-sample-data/large-anon.ssrf.xz > subsurface/dives/large-anon.ssrf
+popd
