@@ -44,6 +44,8 @@ cp $BREEZE/icons/actions/16/view-readermode.svg $MC/icons
 cp $BREEZE/icons/actions/24/application-menu.svg $MC/icons
 cp $BREEZE/icons/actions/22/gps.svg $MC/icons
 cp $BREEZE/icons/actions/24/trash-empty.svg $MC/icons
+cp $BREEZE/icons/actions/24/edit-copy.svg $MC/icons
+cp $BREEZE/icons/actions/24/edit-paste.svg $MC/icons
 cp $BREEZE/icons/actions/24/list-add.svg $MC/icons
 cp $BREEZE/icons/actions/22/handle-left.svg $MC/icons
 cp $BREEZE/icons/actions/22/handle-right.svg $MC/icons
