@@ -321,7 +321,7 @@ static void smtk_build_location(MdbHandle *mdb, char *idx, struct dive_site **lo
 	MdbTableDef *table;
 	MdbColumn *col[MDB_MAX_COLS];
 	char *bound_values[MDB_MAX_COLS];
-	int i;
+	int i, rc;
 	uint32_t d;
 	struct dive_site *ds;
 	location_t loc;
@@ -333,9 +333,14 @@ static void smtk_build_location(MdbHandle *mdb, char *idx, struct dive_site **lo
 	table = smtk_open_table(mdb, "Site", col, bound_values);
 	if (!table)
 		return;
-
-	for (i = 1; i <= atoi(idx); i++)
-		mdb_fetch_row(table);
+	do {
+		rc = mdb_fetch_row(table);
+	} while (strcasecmp(col[0]->bind_ptr, idx) && rc != 0);
+	if (rc == 0) {
+		smtk_free(bound_values, table->num_cols);
+		mdb_free_tabledef(table);
+		return;
+	}
 	loc_idx = copy_string(col[2]->bind_ptr);
 	site = copy_string(col[1]->bind_ptr);
 	loc = create_location(strtod(col[6]->bind_ptr, NULL), strtod(col[7]->bind_ptr, NULL));
@@ -360,8 +365,17 @@ static void smtk_build_location(MdbHandle *mdb, char *idx, struct dive_site **lo
 	/* Read data from Location table, linked to Site by loc_idx */
 	table = smtk_open_table(mdb, "Location", col, bound_values);
 	mdb_rewind_table(table);
-	for (i = 1; i <= atoi(loc_idx); i++)
-		mdb_fetch_row(table);
+	do {
+		rc =mdb_fetch_row(table);
+	} while (strcasecmp(col[0]->bind_ptr, loc_idx) && rc != 0);
+	if (rc == 0){
+		smtk_free(bound_values, table->num_cols);
+		mdb_free_tabledef(table);
+		if(notes)
+			free(notes);
+		return;
+	}
+
 	/*
 	 * Create a string for Subsurface's dive site structure with coordinates
 	 * if available, if the site's name doesn't previously exists.
