@@ -1,8 +1,8 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "testmerge.h"
-#include "core/dive.h"
-#include "core/divelist.h"
+#include "core/divesite.h"
 #include "core/file.h"
+#include "core/trip.h"
 #include <QTextStream>
 
 void TestMerge::initTestCase()
@@ -22,10 +22,12 @@ void TestMerge::testMergeEmpty()
 	 * check that we correctly merge mixed cylinder dives
 	 */
 	struct dive_table table = { 0 };
-	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test47.xml", &table), 0);
-	process_imported_dives(&table, false, false);
-	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test48.xml", &table), 0);
-	process_imported_dives(&table, false, false);
+	struct trip_table trips = { 0 };
+	struct dive_site_table sites = { 0 };
+	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test47.xml", &table, &trips, &sites), 0);
+	add_imported_dives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS);
+	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test48.xml", &table, &trips, &sites), 0);
+	add_imported_dives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS);
 	QCOMPARE(save_dives("./testmerge47+48.ssrf"), 0);
 	QFile org(SUBSURFACE_TEST_DATA "/dives/test47+48.xml");
 	org.open(QFile::ReadOnly);
@@ -46,12 +48,14 @@ void TestMerge::testMergeBackwards()
 	 * check that we correctly merge mixed cylinder dives
 	 */
 	struct dive_table table = { 0 };
-	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test48.xml", &table), 0);
-	process_imported_dives(&table, false, false);
-	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test47.xml", &table), 0);
-	process_imported_dives(&table, false, false);
+	struct trip_table trips = { 0 };
+	struct dive_site_table sites = { 0 };
+	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test48.xml", &table, &trips, &sites), 0);
+	add_imported_dives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS);
+	QCOMPARE(parse_file(SUBSURFACE_TEST_DATA "/dives/test47.xml", &table, &trips, &sites), 0);
+	add_imported_dives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS);
 	QCOMPARE(save_dives("./testmerge47+48.ssrf"), 0);
-	QFile org(SUBSURFACE_TEST_DATA "/dives/test47+48.xml");
+	QFile org(SUBSURFACE_TEST_DATA "/dives/test48+47.xml");
 	org.open(QFile::ReadOnly);
 	QFile out("./testmerge47+48.ssrf");
 	out.open(QFile::ReadOnly);
